//=============================================================================
// RPGツクールMZ - LL_LanguageOption.js v1.0.0
//-----------------------------------------------------------------------------
// ルルの教会 (Lulu's Church)
// https://nine-yusha.com/
//
// Secondary use of this plugin is not permitted.
//=============================================================================

/*:
 * @target MZ
 * @plugindesc 言語設定オプションを追加します。
 * @author ルルの教会
 * @url https://nine-yusha.com/plugin/
 *
 * @help LL_LanguageOption.js
 *
 * 言語設定オプションを追加します。
 *
 * 1. プラグインパラメータで対応する言語設定リストを作成します。
 *    コマンド名やステータス名などシステム用語の翻訳はこちらでおこないます。
 *    またタイトル画面の設定も言語毎に設定が可能です。
 *
 * 2. データベース登録名の翻訳は、下記のタグをメモ欄に記述します。
 *    "_1"の部分は言語設定リストの登録番号です。
 *    初期の日本語を0とし、例えばEnglishを追加した場合は1になります。
 *    [アクター]
 *      <name_1:名前>
 *      <nickname_1:二つ名>
 *      <profile_1:プロフィール>
 *    [職業]
 *      <name_1:名前>
 *    [アイテム、武器、防具]
 *      <name_1:名前>
 *      <description_1:説明>
 *
 * プラグインコマンド:
 *   言語設定の切替: 言語設定を切り替えます。
 *
 * 利用規約:
 *   このプラグインの二次利用、二次配布は禁止させていただきます。
 *
 * 作者: ルルの教会
 * 作成日: 2023/1/3
 *
 * @param languages
 * @text 言語設定リスト
 * @desc 対応する言語設定リストを作成します。
 * @default ["{\"name\":\"日本語\",\"termBasics\":\"\",\"termParams\":\"\",\"termCommands\":\"\",\"termMessages\":\"\",\"types\":\"\",\"currencyUnit\":\"\",\"titleSettings\":\"\",\"titleText\":\"\",\"titles1\":\"\",\"titles2\":\"\"}","{\"name\":\"English\",\"termBasics\":\"{\\\"0\\\":\\\"Level\\\",\\\"1\\\":\\\"\\\",\\\"2\\\":\\\"HP\\\",\\\"3\\\":\\\"\\\",\\\"4\\\":\\\"MP\\\",\\\"5\\\":\\\"\\\",\\\"6\\\":\\\"TP\\\",\\\"7\\\":\\\"\\\",\\\"8\\\":\\\"EXP\\\",\\\"9\\\":\\\"\\\"}\",\"termParams\":\"{\\\"0\\\":\\\"Max HP\\\",\\\"1\\\":\\\"Max MP\\\",\\\"2\\\":\\\"Attack\\\",\\\"3\\\":\\\"Defense\\\",\\\"4\\\":\\\"M.Attack\\\",\\\"5\\\":\\\"M.Defense\\\",\\\"6\\\":\\\"Agility\\\",\\\"7\\\":\\\"Luck\\\",\\\"8\\\":\\\"Hit\\\",\\\"9\\\":\\\"Evasion\\\"}\",\"termCommands\":\"{\\\"0\\\":\\\"Fight\\\",\\\"1\\\":\\\"Escape\\\",\\\"2\\\":\\\"Attack\\\",\\\"3\\\":\\\"Guard\\\",\\\"4\\\":\\\"Item\\\",\\\"5\\\":\\\"Skill\\\",\\\"6\\\":\\\"Equip\\\",\\\"7\\\":\\\"Status\\\",\\\"8\\\":\\\"Formation\\\",\\\"9\\\":\\\"Save\\\",\\\"10\\\":\\\"Game End\\\",\\\"11\\\":\\\"Options\\\",\\\"12\\\":\\\"Weapon\\\",\\\"13\\\":\\\"Armor\\\",\\\"14\\\":\\\"Key Item\\\",\\\"15\\\":\\\"Equip\\\",\\\"16\\\":\\\"Optimize\\\",\\\"17\\\":\\\"Clear\\\",\\\"18\\\":\\\"New Game\\\",\\\"19\\\":\\\"Continue\\\",\\\"21\\\":\\\"To Title\\\",\\\"22\\\":\\\"Cancel\\\",\\\"24\\\":\\\"Buy\\\",\\\"25\\\":\\\"Sell\\\"}\",\"termMessages\":\"{\\\"changeLanguage\\\":\\\"Language\\\",\\\"alwaysDash\\\":\\\"Always Dash\\\",\\\"commandRemember\\\":\\\"Command Remember\\\",\\\"touchUI\\\":\\\"Touch UI\\\",\\\"bgmVolume\\\":\\\"BGM Volume\\\",\\\"bgsVolume\\\":\\\"BGS Volume\\\",\\\"meVolume\\\":\\\"ME Volume\\\",\\\"seVolume\\\":\\\"SE Volume\\\",\\\"possession\\\":\\\"Possession\\\",\\\"expTotal\\\":\\\"Current %1\\\",\\\"expNext\\\":\\\"To Next %1\\\",\\\"saveMessage\\\":\\\"Which file would you like to save to?\\\",\\\"loadMessage\\\":\\\"Which file would you like to load?\\\",\\\"file\\\":\\\"File\\\",\\\"autosave\\\":\\\"Autosave\\\",\\\"partyName\\\":\\\"%1's Party\\\",\\\"emerge\\\":\\\"%1 emerged!\\\",\\\"preemptive\\\":\\\"%1 got the upper hand!\\\",\\\"surprise\\\":\\\"%1 was surprised!\\\",\\\"escapeStart\\\":\\\"%1 has started to escape!\\\",\\\"escapeFailure\\\":\\\"However, it was unable to escape!\\\",\\\"victory\\\":\\\"%1 was victorious!\\\",\\\"defeat\\\":\\\"%1 was defeated.\\\",\\\"obtainExp\\\":\\\"%1 %2 received!\\\",\\\"obtainGold\\\":\\\"%1\\\\\\\\G found!\\\",\\\"obtainItem\\\":\\\"%1 found!\\\",\\\"levelUp\\\":\\\"%1 is now %2 %3!\\\",\\\"obtainSkill\\\":\\\"%1 learned!\\\",\\\"useItem\\\":\\\"%1 uses %2!\\\",\\\"criticalToEnemy\\\":\\\"An excellent hit!!\\\",\\\"criticalToActor\\\":\\\"A painful blow!!\\\",\\\"actorDamage\\\":\\\"%1 took %2 damage!\\\",\\\"actorRecovery\\\":\\\"%1 recovered %2 %3!\\\",\\\"actorGain\\\":\\\"%1 gained %2 %3!\\\",\\\"actorLoss\\\":\\\"%1 lost %2 %3!\\\",\\\"actorDrain\\\":\\\"%1 was drained of %2 %3!\\\",\\\"actorNoDamage\\\":\\\"%1 took no damage!\\\",\\\"actorNoHit\\\":\\\"Miss! %1 took no damage!\\\",\\\"enemyDamage\\\":\\\"%1 took %2 damage!\\\",\\\"enemyRecovery\\\":\\\"%1 recovered %2 %3!\\\",\\\"enemyGain\\\":\\\"%1 gained %2 %3!\\\",\\\"enemyLoss\\\":\\\"%1 lost %2 %3!\\\",\\\"enemyDrain\\\":\\\"%1 was drained of %2 %3!\\\",\\\"enemyNoDamage\\\":\\\"%1 took no damage!\\\",\\\"enemyNoHit\\\":\\\"Miss! %1 took no damage!\\\",\\\"evasion\\\":\\\"%1 evaded the attack!\\\",\\\"magicEvasion\\\":\\\"%1 nullified the magic!\\\",\\\"magicReflection\\\":\\\"%1 reflected the magic!\\\",\\\"counterAttack\\\":\\\"%1 made a counterattack!\\\",\\\"substitute\\\":\\\"%1 protected %2!\\\",\\\"buffAdd\\\":\\\"%1's %2 went up!\\\",\\\"debuffAdd\\\":\\\"%1's %2 went down!\\\",\\\"buffRemove\\\":\\\"%1's %2 returned to normal!\\\",\\\"actionFailure\\\":\\\"There was no effect on %1!\\\"}\",\"types\":\"{\\\"elements\\\":\\\"[\\\\\\\"Physical\\\\\\\",\\\\\\\"Fire\\\\\\\",\\\\\\\"Ice\\\\\\\",\\\\\\\"Thunder\\\\\\\",\\\\\\\"Water\\\\\\\",\\\\\\\"Earth\\\\\\\",\\\\\\\"Wind\\\\\\\",\\\\\\\"Light\\\\\\\",\\\\\\\"Darkness\\\\\\\"]\\\",\\\"skillTypes\\\":\\\"[\\\\\\\"Magic\\\\\\\",\\\\\\\"Special\\\\\\\"]\\\",\\\"equipTypes\\\":\\\"[\\\\\\\"Weapon\\\\\\\",\\\\\\\"Shield\\\\\\\",\\\\\\\"Head\\\\\\\",\\\\\\\"Body\\\\\\\",\\\\\\\"Accessory\\\\\\\"]\\\"}\",\"currencyUnit\":\"\",\"titleSettings\":\"\",\"titleText\":\"\",\"titles1\":\"\",\"titles2\":\"\"}"]
 * @type struct<languageLists>[]
 *
 * @param variableId
 * @text 言語番号格納変数
 * @desc 現在設定中の言語番号をこの変数に格納します。
 * @type variable
 *
 * @command setLanguage
 * @text 言語設定の切替
 * @desc 言語設定を切り替えます。
 *
 * @arg languageNumber
 * @text 言語設定リスト番号
 * @desc 切替する言語設定リストの番号を指定します。
 * 初期の日本語を0とし、登録順の連番から指定します。
 * @type number
 * @default 0
 */

/*~struct~languageLists:
 *
 * @param name
 * @text 言語名
 * @desc 設定を追加する言語名です。
 * オプションの選択肢で表示される言語名になります。
 * @default
 * @type string
 *
 * @param termBasics
 * @text 基本ステータス
 * @desc 基本ステータスの翻訳リストを定義します。
 * @type struct<basics>
 *
 * @param termParams
 * @text 能力値
 * @desc 能力値の翻訳リストを定義します。
 * @type struct<params>
 *
 * @param termCommands
 * @text コマンド
 * @desc コマンドの翻訳リストを定義します。
 * @type struct<commands>
 *
 * @param termMessages
 * @text メッセージ
 * @desc システムメッセージの翻訳リストを定義します。
 * @type struct<messages>
 *
 * @param types
 * @text タイプ
 * @desc タイプの翻訳リストを定義します。
 * @type struct<types>
 *
 * @param currencyUnit
 * @text 通貨単位
 * @desc 通貨単位です。
 * @type string
 *
 * @param titleSettings
 * @text タイトル画面の設定
 * @desc ※この項目は使用しません
 *
 * @param titleText
 * @text ゲームタイトル
 * @desc タイトルとして表示する文字列です。
 * 「ゲームタイトルの描画」が無効の時は反映されません。
 * @type string
 * @parent titleSettings
 *
 * @param titles1
 * @text 背景1
 * @desc 背景1として表示する画像を選択します。
 * @dir img/titles1
 * @type file
 * @require 1
 * @parent titleSettings
 *
 * @param titles2
 * @text 背景2
 * @desc 背景2として表示する画像を選択します。
 * @dir img/titles2
 * @type file
 * @require 1
 * @parent titleSettings
 */

/*~struct~basics:
 *
 * @param 0
 * @text レベル
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 1
 * @text レベル(略)
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 2
 * @text HP
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 3
 * @text HP(略)
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 4
 * @text MP
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 5
 * @text MP(略)
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 6
 * @text TP
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 7
 * @text TP(略)
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 8
 * @text 経験値
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 9
 * @text 経験値(略)
 * @desc 翻訳を入力します。
 * @type string
 */

/*~struct~params:
 *
 * @param 0
 * @text 最大HP
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 1
 * @text 最大MP
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 2
 * @text 攻撃力
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 3
 * @text 防御力
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 4
 * @text 魔法力
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 5
 * @text 魔法防御
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 6
 * @text 敏捷性
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 7
 * @text 運
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 8
 * @text 命中率
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 9
 * @text 回避率
 * @desc 翻訳を入力します。
 * @type string
 */

/*~struct~commands:
 *
 * @param 0
 * @text 戦う
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 1
 * @text 逃げる
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 2
 * @text 攻撃
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 3
 * @text 防御
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 4
 * @text アイテム
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 5
 * @text スキル
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 6
 * @text 装備
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 7
 * @text ステータス
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 8
 * @text 並び替え
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 9
 * @text セーブ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 10
 * @text ゲーム終了
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 11
 * @text オプション
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 12
 * @text 武器
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 13
 * @text 防具
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 14
 * @text 大事なもの
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 15
 * @text 装備2
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 16
 * @text 最強装備
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 17
 * @text 全て外す
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 18
 * @text ニューゲーム
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 19
 * @text コンティニュー
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 21
 * @text タイトルへ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 22
 * @text やめる
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 24
 * @text 購入する
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param 25
 * @text 売却する
 * @desc 翻訳を入力します。
 * @type string
 */

/*~struct~messages:
 *
 * @param changeLanguage
 * @text 言語切替
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param alwaysDash
 * @text 常時ダッシュ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param commandRemember
 * @text コマンド記憶
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param touchUI
 * @text タッチUI
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param bgmVolume
 * @text BGM 音量
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param bgsVolume
 * @text BGS 音量
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param meVolume
 * @text ME 音量
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param seVolume
 * @text SE 音量
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param possession
 * @text 持っている数
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param expTotal
 * @text 現在の経験値
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param expNext
 * @text 次のレベルまで
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param saveMessage
 * @text セーブメッセージ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param loadMessage
 * @text ロードメッセージ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param file
 * @text ファイル
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param autosave
 * @text オートセーブ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param partyName
 * @text パーティ名
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param emerge
 * @text 出現
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param preemptive
 * @text 先制攻撃
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param surprise
 * @text 不意打ち
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param escapeStart
 * @text 逃走開始
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param escapeFailure
 * @text 逃走失敗
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param victory
 * @text 勝利
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param defeat
 * @text 敗北
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param obtainExp
 * @text 経験値獲得
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param obtainGold
 * @text お金獲得
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param obtainItem
 * @text アイテム獲得
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param levelUp
 * @text レベルアップ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param obtainSkill
 * @text スキル習得
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param useItem
 * @text アイテム使用
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param criticalToEnemy
 * @text 敵に会心
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param criticalToActor
 * @text 味方に会心
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param actorDamage
 * @text 味方ダメージ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param actorRecovery
 * @text 味方回復
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param actorGain
 * @text 味方ポイント増加
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param actorLoss
 * @text 味方ポイント減少
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param actorDrain
 * @text 味方ポイント吸収
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param actorNoDamage
 * @text 味方ノーダメージ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param actorNoHit
 * @text 味方に命中せず
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param enemyDamage
 * @text 敵ダメージ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param enemyRecovery
 * @text 敵回復
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param enemyGain
 * @text 敵ポイント増加
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param enemyLoss
 * @text 敵ポイント減少
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param enemyDrain
 * @text 敵ポイント吸収
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param enemyNoDamage
 * @text 敵ノーダメージ
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param enemyNoHit
 * @text 敵に命中せず
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param evasion
 * @text 回避
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param magicEvasion
 * @text 魔法回避
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param magicReflection
 * @text 魔法反射
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param counterAttack
 * @text 反撃
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param substitute
 * @text 身代わり
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param buffAdd
 * @text 強化
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param debuffAdd
 * @text 弱体
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param buffRemove
 * @text 強化・弱体の解除
 * @desc 翻訳を入力します。
 * @type string
 *
 * @param actionFailure
 * @text 行動失敗
 * @desc 翻訳を入力します。
 * @type string
 */

/*~struct~types:
 *
 * @param elements
 * @text 属性
 * @desc 翻訳を入力します。
 * データベースの登録数と同じ数で設定してください。
 * @type string[]
 *
 * @param skillTypes
 * @text スキルタイプ
 * @desc 翻訳を入力します。
 * データベースの登録数と同じ数で設定してください。
 * @type string[]
 *
 * @param equipTypes
 * @text 装備タイプ
 * @desc 翻訳を入力します。
 * データベースの登録数と同じ数で設定してください。
 * @type string[]
 */

(() => {
	"use strict";
	const pluginName = "LL_LanguageOption";

	const parameters = PluginManager.parameters(pluginName);
	const paramJsonParse = function(key, value) {
		try {
			return JSON.parse(value);
		} catch(e) {
			return value;
		}
	};

    const languages = JSON.parse(JSON.stringify(String(parameters["languages"] || ""), paramJsonParse));
	const variableId = Number(parameters["variableId"] || 0);


	//-----------------------------------------------------------------------------
	// プラグインコマンド: 言語の変更
	//-----------------------------------------------------------------------------
	PluginManager.registerCommand(pluginName, "setLanguage", args => {
		const changeLanguage = Number(args.languageNumber || 0);
		ConfigManager.changeLanguage = changeLanguage;
		setDatabaseRename();
	});

	//-----------------------------------------------------------------------------
	// 翻訳設定を取得
	//-----------------------------------------------------------------------------
	const getLanguageSetting = (type, id = null) => {
		const changeLanguage = ConfigManager.changeLanguage;
		if (languages[changeLanguage]) {
			switch (type) {
				case "title1":
					return languages[changeLanguage].titles1;
				case "title2":
					return languages[changeLanguage].titles2;
				case "titleText":
					return languages[changeLanguage].titleText;
				case "currencyUnit":
					return languages[changeLanguage].currencyUnit;
				case "termBasics":
					return languages[changeLanguage].termBasics[id];
				case "termParams":
					return languages[changeLanguage].termCommands[id];
				case "termCommands":
					return languages[changeLanguage].termCommands[id];
				case "termMessages":
					return languages[changeLanguage].termMessages[id];
			}
		}
		return null;
	};

	//-----------------------------------------------------------------------------
	// データベース名をリネーム (翻訳)
	//-----------------------------------------------------------------------------
	const setDatabaseRename = () => {
		const changeLanguage = ConfigManager.changeLanguage;
		// アクター
		$dataActors.forEach((item) => {
			if (item) {
				const actor = $gameActors.actor(item.id);
				// 名前
				actor.setRename(item.meta["name_" + changeLanguage] || item.name);
				// 二つ名
				actor.setReNickname(item.meta["nickname_" + changeLanguage] || item.nickname);
				// プロフィール
				actor.setReProfile(item.meta["profile_" + changeLanguage] || item.profile);
			}
		});
		// 職業
		$dataClasses.forEach((item) => {
			if (item) {
				// 名前
				if (!item.iniName) item.iniName = item.name;
				item.name = item.meta["name_" + changeLanguage] || item.iniName;
			}
		});
		// アイテム
		$dataItems.forEach((item) => {
			if (item) {
				// 名前
				if (!item.iniName) item.iniName = item.name;
				item.name = item.meta["name_" + changeLanguage] || item.iniName;
				// 説明
				if (!item.iniDescription) item.iniDescription = item.description;
				item.description = item.meta["description_" + changeLanguage] || item.iniDescription;
			}
		});
		// 武器
		$dataWeapons.forEach((item) => {
			if (item) {
				// 名前
				if (!item.iniName) item.iniName = item.name;
				item.name = item.meta["name_" + changeLanguage] || item.iniName;
				// 説明
				if (!item.iniDescription) item.iniDescription = item.description;
				item.description = item.meta["description_" + changeLanguage] || item.iniDescription;
			}
		});
		// 防具
		$dataArmors.forEach((item) => {
			if (item) {
				// 名前
				if (!item.iniName) item.iniName = item.name;
				item.name = item.meta["name_" + changeLanguage] || item.iniName;
				// 説明
				if (!item.iniDescription) item.iniDescription = item.description;
				item.description = item.meta["description_" + changeLanguage] || item.iniDescription;
			}
		});

		// タイプ
		if (languages[changeLanguage]) {
			// 属性
			let elements = languages[changeLanguage].types.elements;
			if (!$dataSystem.elementsIni) $dataSystem.elementsIni = $dataSystem.elements;
			if (elements && elements.length > 0) {
				elements = JSON.parse(JSON.stringify(elements));
				elements.unshift("");
				$dataSystem.elements = elements;
			} else {
				$dataSystem.elements = $dataSystem.elementsIni;
			}
			// スキルタイプ
			let skillTypes = languages[changeLanguage].types.skillTypes;
			if (!$dataSystem.skillTypesIni) $dataSystem.skillTypesIni = $dataSystem.skillTypes;
			if (skillTypes && skillTypes.length > 0) {
				skillTypes = JSON.parse(JSON.stringify(skillTypes));
				skillTypes.unshift("");
				$dataSystem.skillTypes = skillTypes;
			} else {
				$dataSystem.skillTypes = $dataSystem.skillTypesIni;
			}
			// 装備タイプ
			let equipTypes = languages[changeLanguage].types.equipTypes;
			if (!$dataSystem.equipTypesIni) $dataSystem.equipTypesIni = $dataSystem.equipTypes;
			if (equipTypes && equipTypes.length > 0) {
				equipTypes = JSON.parse(JSON.stringify(equipTypes));
				equipTypes.unshift("");
				$dataSystem.equipTypes = equipTypes;
			} else {
				$dataSystem.equipTypes = $dataSystem.equipTypesIni;
			}
		}
		// 言語番号を変数に格納
		$gameVariables.setValue(variableId, changeLanguage);
	};


	//-----------------------------------------------------------------------------
	// Scene_Title
	//

	const _Scene_Title_createBackground = Scene_Title.prototype.createBackground;
	Scene_Title.prototype.createBackground = function() {
		_Scene_Title_createBackground.apply(this, arguments);

		// タイトル画面背景を置き換え
		const titles1 = getLanguageSetting("title1");
		const titles2 = getLanguageSetting("title2");
		if (titles1 || titles2) {
			this._backSprite1.bitmap = ImageManager.loadTitle1(titles1);
			this._backSprite2.bitmap = ImageManager.loadTitle2(titles2);
		}
	};

	const _Scene_Title_drawGameTitle = Scene_Title.prototype.drawGameTitle;
	Scene_Title.prototype.drawGameTitle = function() {
		_Scene_Title_drawGameTitle.apply(this, arguments);

		// タイトル描画を置き換え
		const titleText = getLanguageSetting("titleText");
		if (titleText) {
			const x = 20;
			const y = Graphics.height / 4;
			const maxWidth = Graphics.width - x * 2;
			const bitmap = this._gameTitleSprite.bitmap;
			bitmap.fontFace = $gameSystem.mainFontFace();
			bitmap.outlineColor = "black";
			bitmap.outlineWidth = 8;
			bitmap.fontSize = 72;
			bitmap.clear();
			bitmap.drawText(titleText, x, y, maxWidth, 48, "center");
		}
	};

	//-----------------------------------------------------------------------------
	// Scene_Options
	//

	const _Scene_Options_maxCommands = Scene_Options.prototype.maxCommands;
	Scene_Options.prototype.maxCommands = function() {
		// Increase this value when adding option items.
		let value = _Scene_Options_maxCommands.call(this);
		return value += 1;
	};


	//-----------------------------------------------------------------------------
	// Window_Options
	//

	const _Window_Options_addGeneralOptions = Window_Options.prototype.addGeneralOptions;
	Window_Options.prototype.addGeneralOptions = function() {
		this.addCommand(TextManager.changeLanguage || "言語切替", "changeLanguage");
		_Window_Options_addGeneralOptions.apply(this, arguments);
	};

	Window_Options.prototype.isChangeLanguageSymbol = function(symbol) {
		return symbol.includes("changeLanguage");
	};

	const _Window_Options_statusText = Window_Options.prototype.statusText;
	Window_Options.prototype.statusText = function(index) {
		const symbol = this.commandSymbol(index);
	    const value = this.getConfigValue(symbol);
		if (this.isChangeLanguageSymbol(symbol)) {
			return languages[value].name;
		} else {
			return _Window_Options_statusText.apply(this, arguments);
		}
	};

	const _Window_Options_processOk = Window_Options.prototype.processOk;
	Window_Options.prototype.processOk = function() {
		const index = this.index();
		const symbol = this.commandSymbol(index);
		if (this.isChangeLanguageSymbol(symbol)) {
			this.changeLanguage(symbol, 1);
		} else {
			_Window_Options_processOk.apply(this, arguments);
		}
	};

	const _Window_Options_cursorRight = Window_Options.prototype.cursorRight;
	Window_Options.prototype.cursorRight = function() {
		const index = this.index();
		const symbol = this.commandSymbol(index);
		if (this.isChangeLanguageSymbol(symbol)) {
			this.changeLanguage(symbol, 1);
		} else {
			_Window_Options_cursorRight.apply(this, arguments);
		}
	};

	const _Window_Options_cursorLeft = Window_Options.prototype.cursorLeft;
	Window_Options.prototype.cursorLeft = function() {
		const index = this.index();
		const symbol = this.commandSymbol(index);
		if (this.isChangeLanguageSymbol(symbol)) {
			this.changeLanguage(symbol, -1);
		} else {
			_Window_Options_cursorLeft.apply(this, arguments);
		}
	};

	Window_Options.prototype.changeLanguage = function(symbol, select) {
		const lastValue = this.getConfigValue(symbol);
		let value = this.getConfigValue(symbol);
		value += select;
		if (value >= languages.length) {
			value = 0;
		} else if (value < 0) {
			value = languages.length - 1;
		}
		if (lastValue !== value) {
			this.setConfigValue(symbol, value);
			this.playCursorSound();
			// ウィンドウコマンド名を切替
			this.refresh();
			// データベースリネーム
			setDatabaseRename();
		}
	};


	//-----------------------------------------------------------------------------
	// ConfigManager
	//

	ConfigManager.changeLanguage = 0;

	const _ConfigManager_makeData = ConfigManager.makeData;
	ConfigManager.makeData = function() {
		const config = _ConfigManager_makeData.apply(this, arguments);
        config.changeLanguage = this.changeLanguage;
        return config;
	};

	const _ConfigManager_applyData = ConfigManager.applyData;
    ConfigManager.applyData = function(config) {
        _ConfigManager_applyData.apply(this, arguments);
        this.changeLanguage = this.readLanguage(config, 'changeLanguage');
    };

	ConfigManager.readLanguage = function(config, name) {
		if (name in config) {
			return Number(config[name]).clamp(0, languages.length - 1);
		} else {
			return 0;
		}
	};


	//-----------------------------------------------------------------------------
	// TextManager
	//

	Object.defineProperties(TextManager, {
		changeLanguage: TextManager.getter("message", "changeLanguage")
	});

	Object.defineProperty(TextManager, "currencyUnit", {
		get: function() {
			// 翻訳が設定されている場合、置き換える
			return getLanguageSetting("currencyUnit") || $dataSystem.currencyUnit;
		},
		configurable: true
	});

	const _TextManager_basic = TextManager.basic;
	TextManager.basic = function(basicId) {
		// 翻訳が設定されている場合、置き換える
		return getLanguageSetting("termBasics", basicId) || _TextManager_basic.apply(this, arguments);
	};

	const _TextManager_param = TextManager.param;
	TextManager.param = function(paramId) {
		// 翻訳が設定されている場合、置き換える
		return getLanguageSetting("termParams", paramId) || _TextManager_param.apply(this, arguments);
	};


	const _TextManager_command = TextManager.command;
	TextManager.command = function(commandId) {
		// 翻訳が設定されている場合、置き換える
		return getLanguageSetting("termCommands", commandId) || _TextManager_command.apply(this, arguments);
	};

	const _TextManager_message = TextManager.message;
	TextManager.message = function(messageId) {
		// 翻訳が設定されている場合、置き換える
		return getLanguageSetting("termMessages", messageId) || _TextManager_message.apply(this, arguments);
	};


	//-----------------------------------------------------------------------------
	// DataManager
	//

	const _DataManager_createGameObjects = DataManager.createGameObjects;
	DataManager.createGameObjects = function() {
		_DataManager_createGameObjects.apply(this, arguments);
		setDatabaseRename();
	};

	const _DataManager_extractSaveContents = DataManager.extractSaveContents;
	DataManager.extractSaveContents = function(contents) {
		_DataManager_extractSaveContents.apply(this, arguments);
		setDatabaseRename();
	};


	//-----------------------------------------------------------------------------
	// Game_Actor
	//

	const _Game_Actor_initMembers = Game_Actor.prototype.initMembers;
	Game_Actor.prototype.initMembers = function() {
		_Game_Actor_initMembers.apply(this, arguments);
		this._nameAfterChange = false;
		this._nicknameAfterChange = false;
		this._profileAfterChange = false;
	};

	const _Game_Actor_setup = Game_Actor.prototype.setup;
	Game_Actor.prototype.setup = function(actorId) {
		_Game_Actor_setup.apply(this, arguments);
		this._nameAfterChange = false;
		this._nicknameAfterChange = false;
		this._profileAfterChange = false;
	};

	const _Game_Actor_setName = Game_Actor.prototype.setName;
	Game_Actor.prototype.setName = function(name) {
		_Game_Actor_setName.apply(this, arguments);
		this._nameAfterChange = true;
	};

	Game_Actor.prototype.setRename = function(name) {
		if (!this._nameAfterChange) {
			this._name = name;
		}
	};

	const _Game_Actor_setNickname = Game_Actor.prototype.setNickname;
	Game_Actor.prototype.setNickname = function(nickname) {
		_Game_Actor_setNickname.apply(this, arguments);
		this._nicknameAfterChange = true;
	};

	Game_Actor.prototype.setReNickname = function(nickname) {
		if (!this._nicknameAfterChange) {
			this._nickname = nickname;
		}
	};

	const _Game_Actor_setProfile = Game_Actor.prototype.setProfile;
	Game_Actor.prototype.setProfile = function(profile) {
		_Game_Actor_setProfile.apply(this, arguments);
		this._profileAfterChange = true;
	};

	Game_Actor.prototype.setReProfile = function(profile) {
		if (!this._profileAfterChange) {
			this._profile = profile;
		}
	};
})();
