


////////////////////////////////////////////////////////////////////////////////////////


/*:
 * @plugindesc ノベルゲーム向けの機能を提供します
 * @author しぐれん
 * 
 * @target MZ
 * @orderAfter MOG_TitleSplashScreen
 * 
 * @url https://siguren400.booth.pm/items/3300534
 * 
 * 
 * @command Show
 * @text バックログを開く
 * 
 * @command ClearAll
 * @text 全てのログをクリアする
 * @desc 保存されているログを全て消します。
 * 
 * 
 * @command GetLogSize
 * @text 現在のログの大きさを取得
 * @arg variableId
 * @text 結果を書き込む変数
 * @type variable
 * @default 0
 * 
 * @command SetAutoMode
 * @text オートモードの設定
 * @desc イベントコマンドからオート設定のON/OFFを切り替えます。
 * @arg automode
 * @type boolean
 * @default true
 * 
 * @command GetAutoMode
 * @text オートモードの状態取得
 * @desc 現在のオート設定の状態を取得します。
 * @arg swtichId
 * @type switch
 * @default 0
 * 
 * @command HasLastVoice
 * @text 最後に再生した音声の有無を取得
 * @desc 音声再生ボタンが有効かどうかを取得します。
 * @arg switchId
 * @default 0
 * 
 * 
 * @command GetAutoWaitTime
 * @text GetAutoWaitTime/オート待ち時間取得
 * @arg variableId
 * @text 結果を書き込む変数
 * @type variable
 * @default 0
 * 
 * @command SetAutoWaitTime
 * @text SetAutoWaitTime/オート待ち時間設定
 * @arg variableId
 * @type variable
 * @default 0
 * 
 * @command SetLogLimitSizeBasic
 * @text ログの保存容量を設定
 * @arg variableId
 * @type variable
 * @default 0
 * 
 * @command GetLogLimitSizeBasic
 * @text ログの保存容量を取得
 * @arg variableId
 * @text 結果を書き込む変数
 * @type variable
 * @default 0
 * 
 * @command SetLogLimitSizeExtends
 * @text ログの予備容量を設定
 * @arg variableId
 * @type variable
 * @default 0
 * 
 * @command GetLogLimitSizeExtends
 * @text ログの予備容量を取得
 * @desc 取得するのはオプションの状態です。
 * @arg variableId
 * @text 結果を書き込む変数
 * @type variable
 * @default 0
 * 
 * @command GetKeepingAutoMode
 * @text オート保持の設定を取得
 * @type switch
 * @default 0
 * 
 * @command GetMachinakaLines
 * @text 街中モードの同時表示数を取得
 * @arg variableId
 * @text 結果を書き込む変数
 * @type variable
 * @default 0
 * 
 * @command SetMachinakaLines
 * @text 街中モードの同時表示数を設定
 * @arg variableId
 * @type variable
 * @default 0
 * 
 * 
 * @command ShowConsloeProxy
 * @text ログ表示用のデータをコンソールに表示
 * 
 * @param menuCommand
 * @text メニューコマンド
 * @type struct<MultiLangString>
 * @desc メニューにログを開くコマンドを追加します。
 * コマンド名が空欄の場合、追加しません。
 * @default {"ja_JP":"","en_US":"","zh_CN":"","ko_KR":"","de_DE":"","fr_FR":"","ru_RU":""}
 * 
 * @param voice
 * @text ボイス設定
 * @desc 「文章の表示」と「SEの再生」を関連付けます。
 * 合致したファイルを音声として、メッセージログに記録します。
 * @type struct<VoiceJA>
 * @default {"regex":"voice","files":"[]"}
 * 
 * @param buttonSetting
 * @text ボタンの全般設定
 * @type struct<ButtonSettingJA>
 * @default {"offsetX":"0","offsetY":"0","windowOverlap":"outside","windowStretchY":"0"}
 * 
 * @param backlogButton
 * @text ログ表示ボタン
 * @type struct<ButtonJA>
 * @default {"x":"0","y":"0","image":"MessageButton","enabledSwitch":"0","pressedSound":"{\"name\":\"Book1\",\"volume\":\"90\",\"pitch\":\"100\",\"pan\":\"0\"}","hot":"{\"x\":\"0\",\"y\":\"256\",\"width\":\"64\",\"height\":\"64\"}","cold":"{\"x\":\"64\",\"y\":\"256\",\"width\":\"64\",\"height\":\"64\"}"}
 * @parent buttonSetting
 * 
 * @param saveButton
 * @text セーブボタン
 * @type struct<ButtonJA>
 * @default {"x":"64","y":"0","image":"MessageButton","enabledSwitch":"0","pressedSound":"{\"name\":\"Book2\",\"volume\":\"90\",\"pitch\":\"100\",\"pan\":\"0\"}","hot":"{\"x\":\"0\",\"y\":\"128\",\"width\":\"64\",\"height\":\"64\"}","cold":"{\"x\":\"64\",\"y\":\"128\",\"width\":\"64\",\"height\":\"64\"}"}
 * @parent buttonSetting
 * 
 * @param loadButton
 * @text ロードボタン
 * @type struct<ButtonJA>
 * @default {"x":"128","y":"0","image":"MessageButton","enabledSwitch":"0","pressedSound":"{\"name\":\"Book2\",\"volume\":\"90\",\"pitch\":\"100\",\"pan\":\"0\"}","hot":"{\"x\":\"0\",\"y\":\"192\",\"width\":\"64\",\"height\":\"64\"}","cold":"{\"x\":\"64\",\"y\":\"192\",\"width\":\"64\",\"height\":\"64\"}"}
 * @parent buttonSetting
 * 
 * @param voiceRepeatButton
 * @text ボイスリプレイボタン
 * @desc 押した場合、最後のボイスをもう一度再生します。
 * @type struct<ButtonJA>
 * @default {"x":"256","y":"0","image":"MessageButton","enabledSwitch":"0","pressedSound":"","hot":"{\"x\":\"0\",\"y\":\"320\",\"width\":\"64\",\"height\":\"64\"}","cold":"{\"x\":\"64\",\"y\":\"320\",\"width\":\"64\",\"height\":\"64\"}"}
 * @parent buttonSetting
 * 
 * @param autoButton
 * @text オートボタン
 * @desc オート状態の場合、
 * 解除されるまでボタンが押されている状態の表示になります。
 * @type struct<ButtonJA>
 * @default {"x":"196","y":"0","image":"MessageButton","enabledSwitch":"0","pressedSound":"{\"name\":\"Key\",\"volume\":\"90\",\"pitch\":\"100\",\"pan\":\"0\"}","hot":"{\"x\":\"0\",\"y\":\"0\",\"width\":\"64\",\"height\":\"64\"}","cold":"{\"x\":\"64\",\"y\":\"0\",\"width\":\"64\",\"height\":\"64\"}"}
 * @parent buttonSetting
 * 
 * @param autoGauge
 * @text オートゲージ
 * @type struct<AutoGauge>
 * @default {"gaugeType":"circle","x":"0","y":"0","width":"10","texture":"","color":"FF0000"}
 * @parent autoButton
 * 
 * @param skipButton
 * @text 既読スキップボタン
 * @desc 押された際に指定スイッチをONにします。
 * 既読スキップの処理はManoUZ_Kidokuを使います。
 * @type struct<ButtonJA>
 * @default {"x":"320","y":"0","image":"MessageButton","hot":"{\"x\":\"0\",\"y\":\"64\",\"width\":\"64\",\"height\":\"64\"}","cold":"{\"x\":\"64\",\"y\":\"64\",\"width\":\"64\",\"height\":\"64\"}","enabledSwitch":"0","pressedSound":"{\"name\":\"Key\",\"volume\":\"90\",\"pitch\":\"100\",\"pan\":\"0\"}"}
 * @parent buttonSetting
 * 
 * @param skipSwitch
 * @text スキップモード時にONにするスイッチ
 * @desc 未設定の場合、スキップボタンを押しても動きません。
 * @type switch
 * @default 0
 * @parent skipButton
 * 
 * @param logWriteSwitch
 * @text ログ書き込み有効化スイッチ
 * @desc 指定したスイッチがONの場合のみ、ログを書き込みます。
 * 未指定の場合、常に書き込みます。
 * @type switch
 * @default 0
 * 
 * @param logWriteOnBattle
 * @text 戦闘中のログ書き込み
 * @desc OFFにすると、戦闘中はログの書き込みを行いません。
 * @type boolean
 * @default false
 * 
 * @param logStyle
 * @type struct<LogStyleJA>
 * @text ログ画面スタイル
 * @desc ログ画面の配置などを設定します。
 * @default {"windowFileName":"Window","background":"","speakerName":"【%1】","choiceFormat":"【%1】：%2","choiceText":"{\"ja_JP\":\"選択肢\",\"en_US\":\"choices\",\"zh_CN\":\"选择\",\"ko_KR\":\"선택\",\"de_DE\":\"Auswahl\",\"fr_FR\":\"Les choix\",\"ru_RU\":\"Выбор\"}","voiceIconIndex":"4"}
 * 
 * @param autoWaitTime
 * @text オート待ち時間
 * @type number
 * @default 360
 * 
 * @param logLimitBasic
 * @text ログ保存数(基本)
 * @desc 古いログを掃除する際に、ここで指定した個数以下にします。
 * @type number
 * @default 40
 * 
 * @param logLimitExtends
 * @text ログ保存数(追加)
 * @desc 保存されたログが基本＋追加を超えた場合、
 * 古いログの破棄を行います。
 * @type number
 * @default 20
 * 
 * @param machinakaModeSwitch
 * @text 街中モード制御スイッチ
 * @desc 指定スイッチがONの間のみ機能を有効化します。
 * @type switch
 * @default 0
 * 
 * @param macinakaModeDefault
 * @text 街中モード初期値
 * @type boolean
 * @default true
 * @parent macinakaMode
 * 
 * @param machinakaModeLines
 * @text 街中モード・表示行数
 * @type number
 * @default 3
 * 
 * @param choiceFormat
 * @text 選択肢の表示形式
 * @type string
 * @desc %1に「選択肢」、%2に項目の文字列が表示されます。
 * @default 【%1】：%2
 * @parent logStyle
 * 
 * @param choiceText
 * @text 選択肢
 * @type struct<MultiLangString>
 * @default {"ja_JP":"選択肢","en_US":"choices","zh_CN":"选择","ko_KR":"선택","de_DE":"Auswahl","fr_FR":"Les choix","ru_RU":"Выбор"}
 * @desc 選択肢の表示名。多言語対応済み。
 * @parent logStyle
 * 
 * @param choiceCancelText
 * @text 選択肢キャンセル時の文章
 * @type struct<MultiLangString>
 * @default {"ja_JP":"キャンセル","en_US":"Cancel","zh_CN":"","ko_KR":"","de_DE":"","fr_FR":"","ru_RU":""}
 * @parent logStyle
 * 
 * @help
 * 以下の機能を提供します
 * ■メッセージログの保存・表示
 * ■メッセージの途中セーブ・ロード実行
 * ■ボイス記録機能
 * 
 * 「文章の表示」によって表示された文章をログとして記録します。
 * 
 * ■ボタンの割り当てについて
 * メッセージの表示中、
 * 以下のシンボルの入力が行われた場合にシーン切り替えを実行します。
 * 内部判定はlongPressedを使用しているので、長押しが必要です。
 * ・セーブ:pageup
 * ・ロード:pagedown
 * ・ログ　:shift
 * 
 * ■ボタン配置について
 * ボタン配置は相対位置で決められています。
 * ボタン領域の四角形は、全てのボタンを収めることができる四角形となります。
 * この四角形の右側がウィンドウの右側と合わさるような位置を基準とします。
 * offsetX,offsetYは、この位置を基準に動かします。
 * 
 * ■途中セーブ機能について
 * メッセージ表示中にセーブ画面を開き、セーブを行えます。
 * トリガーが並列実行のイベントを実行中にセーブを行うと、
 * 不具合が発生することがあります。
 * 
 * ■途中セーブをロードした場合の挙動
 * メッセージを正しく復元するために、イベントの実行状態を巻き戻します。
 * メッセージの文章によって変数などを操作するプラグインと併用すると、
 * 不具合が発生する可能性があります。
 * 
 * ■ログデータが消えている場合
 * プラグインのバージョンが異なる場合、ログデータを初期化します。
 * この場合でもログ以外のセーブデータは読み込み可能です。
 * 
 * ■ボイス記録機能
 * 文章の表示前に「SEの再生」が実行されていると、それをボイスとして記録します。
 * 
 * 効果音が巻き込まれないように、判別方法が用意されています。
 * 効果音はaudio/se/の内部に配置されますが、
 * その中のサブフォルダで登録するかを判定します。
 * ※サブフォルダはツクールMZ ver1.3.1以降の機能です。
 * 対応するのは以下のファイルです。
 * ※以下の設定はパラメータ「ボイスファイル正規表現」が
 * 「voice」の場合の設定方法です。
 * ・フォルダ「audio/se/」内のサブフォルダ「voice」に含まれるファイル
 * ・ファイル名の先頭に「voice」と付くファイル
 * ・専用に登録したファイル(プラグインパラメータ:ボイスファイルリスト参照)
 * 
 * ■メッセージ自動送り
 * 文章の表示が完了した後、一定時間の経過で自動的に次のメッセージを表示します。
 * ボイスがある場合、ボイスの再生完了まで待ちます。
 * 手動でメッセージ送りした場合、ボイスを停止します。
 * 
 * メッセージ自動送りの速度を変更する場合、付属のオプションプラグインを入れてください。
 * 
 * ■ログ画面の開き方
 * ログ画面はメッセージ表示中に以下の操作を押すと開きます。
 * ・shiftキーを押し続ける
 * ・マウスホイール上
 * ・画面内のボタンを押す
 * これ以外にも、プラグインコマンドで呼び出す方法があります。
 * マップ上で自由に呼び出せるようにしたい場合、
 * コモンイベントを利用してプラグインコマンドを呼び出してください。
 * 
 * ■街中モード
 * マップ内を移動して複数のイベントに話しかけた場合を想定した機能です。
 * 同じイベントのイベントのメッセージを記録する場合、
 * 最新の1回分で上書きします。
 * 
 * 街中モードによる表示はスイッチ制御で一時的に無効化できます。
 * 無効化中はログ画面を開いても街中モードの選択ウィンドウが非表示になります。
 * 
 * 
 * 
 * ■利用規約
 * 1.利用可能なプロジェクト
 * ・ゲームの内容(配布および販売方法・年齢制限の有無など)を問わず、どのようなゲームにでもご利用いただけます。
 * 
 * 2.利用条件
 * ・ゲームの配布(販売を含む)の際に、同梱のテキストなどに本プラグインを利用したことを記載してください。
 * ・複数人のチームによるゲーム作成の場合、参加者の内１名以上が本プラグインを購入している必要があります。
 * ・本プラグインを利用するに際し、利用者は自己の責任に基づいて使用するものとします。
 * ・本プラグインを改変しての利用は可能ですが、その場合は(5)で示すサポートの範囲外とします。
 * 
 * 3.禁止事項
 * ・改変の有無に関わらず本プラグインをゲームの配布(販売を含む)以外の方法で、公開・配布・販売する行為。
 * ・配布(販売含む)されたゲームの中から本プラグイン抜き出して使用する行為。
 * ・このプラグインに記載された利用規約を削除・改変する行為。
 * 
 * 4.免責事項
 * 当方は以下の内容についてその責任を負わないものとします。
 * ・本プラグインの更新によるセーブデータの互換性消失
 * ・セーブデータの破損
 * ・ゲームデータの破損
 * ・他のプラグインとの併用による誤作動・不具合
 * ・その他プラグインの使用によって生じた損害
 * 
 * 5.不具合対応(サポート)
 * ・本プラグインの不具合について可能な限り対応しますが、修正を行うことを保証するものではありません。
 * 
 * 9.利用規約の変更について
 * ・この利用規約は予告なく変更されることがあります。
 * 
*/
 /*~struct~PlaySeEN:
 * @param name
 * @type file
 * @dir audio/se/
 * 
 * @param volume
 * @text Volume
 * @desc Adjust Voice File Volume
 * @default 90
 * @min 0
 * @max 100
 * @type number
 *
 * @param pitch
 * @text Pitch
 * @desc Adjust Voice File Pitch
 * @default 100
 * @type number
 *
 * @param pan
 * @text Pan
 * @desc Pan Voice File
 * @default 0
 * @min -100
 * @max 100
 * @type number
  */

 /*~struct~PlaySeJA:
 * @param name
 * @type file
 * @dir audio/se/
 * 
 * @param volume
 * @text 音量
 * @desc ボイスファイルの音量
 * @default 90
 * @min 0
 * @max 100
 * @type number
 *
 * @param pitch
 * @text ピッチ
 * @desc ボイスファイルのピッチ
 * @default 100
 * @type number
 *
 * @param pan
 * @text 左右バランス
 * @desc ボイスファイルの左右バランス
 * @default 0
 * @min -100
 * @max 100
 * @type number
  */
/*~struct~ButtonJA:
 * 
 * @param x
 * @text X座標(相対位置)
 * @desc 基準位置はボタングループで設定。
 * 状況により基準位置は移動します。
 * @type number
 * @default 0
 * 
 * @param y
 * @text Y座標(相対位置)
 * @desc 基準位置はボタングループで設定。
 * 状況により基準位置は移動します。
 * @type number
 * @default 0
 * 
 * @param image
 * @text ボタン画像
 * @desc 空欄にするとボタンと対応した機能が無効になります。
 * @type file
 * @dir img/system/
 * 
 * @param hot
 * @text 押されている時の画像
 * @type struct<Rect>
 * @desc ボタンがクリックされている間に表示する画像。
 * ボタン画像の一部から、指定範囲を切り出して使います。
 * @default {"x":"0","y":"0","width":"64","height":"64"}
 * 
 * @param cold
 * @text 通常時の画像
 * @type struct<Rect>
 * @desc ボタンがクリックされていない間に表示する画像。
 * ボタン画像の一部から、指定範囲を切り出して使います。
 * @default {"x":"0","y":"0","width":"64","height":"64"}
 * 
 * @param enabledSwitch
 * @text 有効化スイッチ
 * @desc 指定したスイッチがONの場合のみボタンを表示します。
 * ニューゲーム時にONになります。未指定の場合、常に有効化。
 * @type switch
 * @default 0
 * 
 * @param pressedSound
 * @text 押された時の音声
 * @type struct<PlaySeJA>
 * 
 */
/*~struct~AutoGauge:
 * 
 * @param gaugeType
 * @type select
 * @option none
 * @option circle
 * @default circle
 * 
 * @param x
 * @type number
 * @default 0
 * 
 * @param y
 * @type number
 * @default 0
 * 
 * @param width
 * @type number
 * @default 10
 * 
 * @param texture
 * @type file
 * @dir img/system/
 * 
 * @param color
 * @type string
 * @default FF0000
*/
/*~struct~ButtonSettingJA:
 * @param offsetX
 * @desc ボタンを横方向に移動します。
 * @type number
 * @min -123456
 * @default 0
 * 
 * @param offsetY
 * @desc ボタンを縦方向に移動します。
 * @type number
 * @min -123456
 * @default 0
 * 
 * @param windowOverlap
 * @text ウィンドウとの重なり
 * @type select
 * @option 内側(ウィンドウが少し大きくなります)
 * @value inside
 * @option 外側(必要に応じて選択肢が移動します)
 * @value outside
 * @option 絶対指定(ほぼ左上原点・メッセージが下側の場合のみ表示)
 * @value absolute
 * @default outside
 * 
 * @param windowStretchY
 * @text ウィンドウの伸縮(Y)
 * @desc ボタン設置用のスペースを確保するときに使います。
 * @type number
 * @min -123456
 * @default 0
 * 
 * @param disableSwitch
 * @text 強制ボタン非表示
 * @desc 指定したスイッチがONの間、全てのボタンを無効化します。
 * @type switch
 * @default 0
 * */
/*~struct~LogStyleJA:
 * @param windowRect
 * @text ウィンドウ配置
 * @type struct<Rect>
 * 
 *
 * @param windowFileName
 * @type file
 * @text ウィンドウ画像
 * @dir img/system
 * @default Window
 * 
 * @param background
 * @text 背景画像
 * @type file
 * @dir img/system
 * @desc ログシーンの背景に使う画像を設定します。
 * 
 * @param freamColor
 * @text 枠線の色(空欄の場合非表示)
 * @desc 文章の間に入れる区切り線の色を指定します。#00FFFF表記
 * @type string
 * @default #00FFFF
 * 
 * @param speakerName
 * @text 名前表示フォーマット
 * @desc 名前を変換して表示します(%1→名前,%2→ボイスアイコン)
 * @type string
 * @default 【%1】%2
 * 
 * 
 * @param voiceIconIndex
 * @text アイコン番号
 * @desc ログ表示の際に、ボイスがあるログにアイコンを表示します。
 * @type number
 * @default 4
 * 
 * 
 * @param lineSpacing
 * @text 行間スペース
 * @type number
 * @default 2
 * 
*/
//通常効果音をボイス扱いするための機能
/*~struct~VoiceJA:
 * @param regex
 * @text ボイスファイル正規表現
 * @desc  正規表現で合致したファイル名を音声として扱います。
 * 内部的には「"^"+"この文字列"+".+"」で処理しています。
 * @type string
 * @default voice
 * 
 * @param files
 * @text ボイスファイルリスト
 * @type file[]
 * @dir audio/se/
 * @desc 指定したファイルをボイスファイルとして扱います。
 * 正規表現で対応できないファイルを対応させる場合に使います。
 * @default []
 * 
 * 
*/


 /*~struct~MultiLangString:
  * @param ja_JP
    @text 日本語

    @param en_US
    @text English

    @param zh_CN
    @text 中文(簡体)
    @desc 我不知道繁體中文，所以目​​前不支持。
    繁体については私が知らないので非対応です。

    @param ko_KR
    @text 한국

    @param de_DE
    @text Deutsche(ドイツ語)

    @param fr_FR
    @text français(フランス語)

    @param ru_RU
    @text русский(ロシア語)
 */



/**
 * @typedef {Object} ManoUZ_LogOptionParametor
 * @property {number} logLimitBasic
 * @property {number} logLimitExtends
 * @property {number} autoWaitTime
 * @property {boolean} keepingAutoMode
 * @property {number} gaugeColor
 * @property {number} machinakaLines
 */
/**
 * @typedef {Object} UZ_AudioFileParam
 * @property {string} name
 * @property {number} pan
 * @property {number} pitch
 * @property {number} pos
 * @property {number} volume
 */

/**
 * @typedef {object} LogManagerExportConcept
 * @property {(option:ManoUZ_LogOptionParametor)=>void} setOptionValue
 * @property {()=>ManoUZ_LogOptionParametor} cloneOptionValue
 * @property {(audio:UZ_AudioFileParam,exParam:any)=>void} playVoice
 */

(function(_0x58694a,_0x12b5c2){const _0x36d226=_0x563b,_0x34229e=_0x58694a();while(!![]){try{const _0x19ca69=-parseInt(_0x36d226(0x1ac))/0x1+parseInt(_0x36d226(0x388))/0x2*(parseInt(_0x36d226(0x19e))/0x3)+parseInt(_0x36d226(0x275))/0x4*(parseInt(_0x36d226(0x20a))/0x5)+parseInt(_0x36d226(0x31e))/0x6+-parseInt(_0x36d226(0x175))/0x7+-parseInt(_0x36d226(0x27f))/0x8+parseInt(_0x36d226(0x192))/0x9*(-parseInt(_0x36d226(0x168))/0xa);if(_0x19ca69===_0x12b5c2)break;else _0x34229e['push'](_0x34229e['shift']());}catch(_0x1c45a9){_0x34229e['push'](_0x34229e['shift']());}}}(_0xeca8,0x2e723));function _0x563b(_0x1a0a23,_0x4b0e54){const _0xeca8b5=_0xeca8();return _0x563b=function(_0x563b00,_0x1fc93e){_0x563b00=_0x563b00-0x12e;let _0x5cc0b9=_0xeca8b5[_0x563b00];return _0x5cc0b9;},_0x563b(_0x1a0a23,_0x4b0e54);}const ManoUZ_MessageLog=(function(){'use strict';const _0x526707=_0x563b;const _0x53d28a=0x1348d12;class _0xea0a06{[_0x526707(0x2e4)](){return'';}[_0x526707(0x340)](){return 0x1;}[_0x526707(0x297)](){return null;}[_0x526707(0x178)](){const _0x25a85e=_0x526707;return!!this[_0x25a85e(0x297)]();}['needsDrawBackground'](){return!![];}[_0x526707(0x21b)](){return null;}[_0x526707(0x2f9)](){return 0x0;}[_0x526707(0x14f)](){return!![];}[_0x526707(0x1da)](){return![];}[_0x526707(0x2a1)](){return 0x0;}}class _0x210b2a extends _0xea0a06{constructor(_0x45da02){const _0x396ebf=_0x526707;super(),this[_0x396ebf(0x2fb)]=_0x45da02;}[_0x526707(0x14f)](){return![];}['item'](){return null;}[_0x526707(0x185)](){return![];}[_0x526707(0x340)](){const _0x47ce5c=_0x526707;return this['_item'][_0x47ce5c(0x196)]();}[_0x526707(0x297)](){const _0x53ee5d=_0x526707;return this['_item'][_0x53ee5d(0x297)]();}[_0x526707(0x178)](){const _0x3a1b62=_0x526707;return this[_0x3a1b62(0x14f)]()&&this[_0x3a1b62(0x2fb)][_0x3a1b62(0x2f5)]();}[_0x526707(0x354)](){return![];}[_0x526707(0x21b)](){const _0x1aa260=_0x526707;return this[_0x1aa260(0x2fb)][_0x1aa260(0x21b)]();}['faceIndex'](){const _0x329698=_0x526707;return this[_0x329698(0x2fb)][_0x329698(0x2f9)]();}['isIconLeft'](){return![];}[_0x526707(0x363)](){return![];}}class _0x4b72e7 extends _0xea0a06{constructor(_0xc1532d){const _0x2272c4=_0x526707;super(),this[_0x2272c4(0x2ab)]=_0xc1532d;}[_0x526707(0x2e4)](){
    const _0x3f684f=_0x526707;return this[_0x3f684f(0x2ab)][_0x3f684f(0x2e4)]();}['needsDrawBackground'](){return!![];}}class _0x4ad5c8 extends _0x210b2a{constructor(_0x21d230){super(_0x21d230);}['isIconLeft'](){return!![];}[_0x526707(0x14f)](){return!![];}['text'](){return this['_item']['speakerName']();}['lineIndex'](){return 0x0;}[_0x526707(0x363)](){return!![];}}class _0x1c2dd8 extends _0x210b2a{constructor(_0x4ae202,_0x2b101c){const _0x8e3483=_0x526707;super(_0x4ae202),this[_0x8e3483(0x137)]=_0x2b101c;}[_0x526707(0x2a1)](){const _0x48479e=_0x526707;return this[_0x48479e(0x137)];}['isIconLeft'](){return![];}[_0x526707(0x14f)](){const _0x2b96b2=_0x526707;return!this[_0x2b96b2(0x2fb)][_0x2b96b2(0x36d)]();}[_0x526707(0x2e4)](){const _0x2b8498=_0x526707;return this['_item'][_0x2b8498(0x2e4)]();}[_0x526707(0x354)](){return!![];}[_0x526707(0x363)](){return this['isTopItem']();}}class _0x3ade85 extends _0x210b2a{constructor(_0x1205a2,_0x20556b){const _0x4c4173=_0x526707;super(_0x1205a2),this[_0x4c4173(0x137)]=_0x20556b;}[_0x526707(0x2e4)](){return'';}[_0x526707(0x14f)](){return![];}[_0x526707(0x2a1)](){const _0x6b1637=_0x526707;return this[_0x6b1637(0x137)];}['needsDrawBackground'](){return![];}}class _0x1925b6{[_0x526707(0x27d)](){}[_0x526707(0x365)](){return[];}['voiceParam'](){return null;}[_0x526707(0x2f5)](){const _0x41106e=_0x526707;return!!this[_0x41106e(0x297)]();}[_0x526707(0x186)](){}[_0x526707(0x1fc)](){return null;}}class _0x1b41ac extends _0x1925b6{constructor(){const _0x223a62=_0x526707;super(),this['_text']='',this[_0x223a62(0x392)]=0x0,this[_0x223a62(0x283)]=null,this[_0x223a62(0x394)]=null,this[_0x223a62(0x315)]=0x0;}[_0x526707(0x20e)](_0x23ec40,_0x905d30,_0x1dabb9){const _0x33c4db=_0x526707;this[_0x33c4db(0x392)]=_0x1dabb9,this['_facename']=_0x905d30,this[_0x33c4db(0x18c)]='',this[_0x33c4db(0x1cb)]=_0x23ec40;}[_0x526707(0x1fc)](){const _0x1891c3=_0x526707;if(!this[_0x1891c3(0x18c)])return null;const _0x23efd0=this['_text']['match'](/([^\r\n]\s*\S.*)/);if(_0x23efd0)return _0x23efd0[0x0];return null;}[_0x526707(0x24b)](_0x4b497c,_0x4fcf28,_0x164e64,_0x10bdb9,_0x1dd127){const _0x5e5aca=_0x526707;this[_0x5e5aca(0x1cb)]=_0x4b497c,this[_0x5e5aca(0x18c)]=_0x4fcf28,this[_0x5e5aca(0x283)]=_0x164e64,this['_faceindex']=_0x10bdb9,this[_0x5e5aca(0x394)]=_0x1dd127;}[_0x526707(0x33d)](_0x16fb81){const _0x3e5eb8=_0x526707;this[_0x3e5eb8(0x315)]+=_0x16fb81;}['text'](){return this['_text'];}[_0x526707(0x189)](){const _0xb09b97=_0x526707;return this[_0xb09b97(0x315)];}[_0x526707(0x196)](){const _0x9d6d13=_0x526707,_0x31faa2=this['hasName']()?0x1:0x0,_0x595d58=!!this['faceName']()?0x4:0x0;return Math[_0x9d6d13(0x358)](_0x595d58,_0x31faa2+this['textLines']());}[_0x526707(0x21b)](){const _0x830690=_0x526707;return this[_0x830690(0x283)];}['faceIndex'](){return this['_faceindex'];}[_0x526707(0x185)](){const _0x4b76aa=_0x526707;return!!this[_0x4b76aa(0x1cb)];}[_0x526707(0x36d)](){const _0x303559=_0x526707;return this[_0x303559(0x1cb)];}[_0x526707(0x297)](){const _0x32e21a=_0x526707;return this[_0x32e21a(0x394)];}['needsVoiceIconRender'](){const _0x486dda=_0x526707;return!!this[_0x486dda(0x394)];}[_0x526707(0x365)](){const _0x171432=_0x526707,_0x48d9be=this['hasName'](),_0x23ed96=_0x48d9be?0x1:0x0,_0x57ca38=new _0x1c2dd8(this,_0x23ed96),_0x15d9c3=[_0x57ca38];if(_0x48d9be){const _0x103ce5=new _0x4ad5c8(this);_0x15d9c3[_0x171432(0x37a)](_0x103ce5);}const _0x31d241=this[_0x171432(0x196)]();for(let _0x336a46=_0x23ed96+0x1;_0x336a46<_0x31d241;++_0x336a46){const _0x2f4017=new _0x3ade85(this,_0x336a46);_0x15d9c3[_0x171432(0x1f2)](_0x2f4017);}return _0x15d9c3;}}class _0x470fe1{constructor(_0x15e234){const _0x341fb1=_0x526707;this['_version']=_0x15e234,this['_machinakaList']=[],this['_logList']=new _0x36c076(),this[_0x341fb1(0x1cd)]=0x0,this[_0x341fb1(0x173)]();}[_0x526707(0x2e5)](_0x381ccf,_0x12e484){const _0x19dfde=_0x526707,_0x236af7=Math['max'](_0x381ccf,_0x12e484);if(this[_0x19dfde(0x31f)][_0x19dfde(0x17f)]>_0x236af7){const _0x1c8c31=Math[_0x19dfde(0x160)](_0x12e484-_0x381ccf),_0xa8c9b5=this[_0x19dfde(0x31f)][_0x19dfde(0x1f6)](_0x1c8c31);this[_0x19dfde(0x31f)]=_0xa8c9b5;}}['addItem'](_0x3f452b){const _0x5c5db1=_0x526707;this[_0x5c5db1(0x357)]&&this[_0x5c5db1(0x357)][_0x5c5db1(0x139)](_0x3f452b);}['version'](){const _0x3f1ca5=_0x526707;return this[_0x3f1ca5(0x2e1)];}[_0x526707(0x334)](){const _0x572853=_0x526707;return this[_0x572853(0x337)];}['setLastCodeIndex'](_0x292d90){const _0x550ca6=_0x526707;this[_0x550ca6(0x337)]=_0x292d90;}['clearLastCodeIndex'](){const _0x98d9c4=_0x526707;this[_0x98d9c4(0x1b9)](NaN);}[_0x526707(0x304)](){const _0x3583fb=_0x526707;return this[_0x3583fb(0x357)]&&!this['_logList']['isEmpty']();}[_0x526707(0x190)](){const _0x546c35=_0x526707,_0x208932=this[_0x546c35(0x31f)]['filter'](_0x422819=>{const _0x2677d9=_0x546c35;if(this['_logList'])return!this[_0x2677d9(0x357)][_0x2677d9(0x36a)](_0x422819[_0x2677d9(0x14a)](),_0x422819[_0x2677d9(0x312)]());return!![];});return this[_0x546c35(0x304)]()&&_0x208932['push'](this[_0x546c35(0x357)]),_0x208932;}[_0x526707(0x28c)](){const _0x210d0b=_0x526707;if(!this[_0x210d0b(0x304)]())return;const _0x3c5b35=this['_machinakaList']['findIndex'](_0x23974d=>{const _0x42efc9=_0x210d0b;return this['_logList'][_0x42efc9(0x36c)](_0x23974d);});_0x3c5b35>=0x0?this[_0x210d0b(0x31f)][_0x3c5b35]=this[_0x210d0b(0x357)]:this['_machinakaList'][_0x210d0b(0x1f2)](this['_logList']),this[_0x210d0b(0x357)]=null;}[_0x526707(0x20c)](_0x10c5a7,_0x4ac2c2){const _0x16ebb=_0x526707,_0x4e7880=new _0x36c076();_0x4e7880[_0x16ebb(0x158)](_0x10c5a7,_0x4ac2c2),this[_0x16ebb(0x357)]=_0x4e7880;}[_0x526707(0x365)](){const _0x327950=_0x526707;if(this[_0x327950(0x357)])return this['_logList']['createProxy']();return[];}[_0x526707(0x204)](){const _0x2ce39e=_0x526707;if(this[_0x2ce39e(0x357)]){const _0x4d1890=this['_logList'][_0x2ce39e(0x29c)]();if(_0x4d1890)return _0x4d1890[_0x2ce39e(0x297)]();}return null;}[_0x526707(0x161)](){}['forceCleanup'](){}[_0x526707(0x32b)](){const _0x38a751=_0x526707,_0x351e6c=new _0x470fe1(this['_version']);return _0x351e6c[_0x38a751(0x31f)]=[],_0x351e6c;}[_0x526707(0x372)](){return 0x0;}}class _0x28ba4a extends _0x1925b6{constructor(_0x1c8b97,_0x1bc15a){const _0x258e6d=_0x526707;super(),this['_text']=_0x1c8b97,this[_0x258e6d(0x1ad)]=_0x1bc15a;}[_0x526707(0x365)](){return[new _0x4b72e7(this)];}[_0x526707(0x2e4)](){const _0x3e90cf=_0x526707;return this[_0x3e90cf(0x18c)];}[_0x526707(0x1fc)](){const _0x12745d=_0x526707;return this[_0x12745d(0x18c)];}}class _0x4a4e93{[_0x526707(0x171)](){return[];}[_0x526707(0x23a)](){const _0x1241e4=_0x526707;return this[_0x1241e4(0x372)]()-0x1;}[_0x526707(0x14a)](){return NaN;}['eventId'](){return NaN;}[_0x526707(0x372)](){const _0x3dccba=_0x526707;return this[_0x3dccba(0x171)]()['length'];}[_0x526707(0x36a)](_0x3248d0,_0x42cf54){const _0x4cce69=_0x526707;
        return this[_0x4cce69(0x14a)]()===_0x3248d0&&this['eventId']()===_0x42cf54;}[_0x526707(0x36c)](_0x95ff29){const _0x3364a5=_0x526707,_0x895a77=this[_0x3364a5(0x14a)](),_0x1ca7b1=this[_0x3364a5(0x312)]();if(isNaN(_0x895a77)||isNaN(_0x1ca7b1))return![];return this['mapId']()===_0x95ff29[_0x3364a5(0x14a)]()&&this[_0x3364a5(0x312)]()===_0x95ff29[_0x3364a5(0x312)]();}['createProxy'](){const _0x1a05fd=_0x526707,_0x21884b=[],_0x18e6be=this[_0x1a05fd(0x171)]();for(const _0x38dcb1 of _0x18e6be){const _0x1db605=_0x38dcb1[_0x1a05fd(0x365)]();_0x21884b[_0x1a05fd(0x1f2)](..._0x1db605);}return _0x21884b;}}class _0x36c076 extends _0x4a4e93{constructor(){const _0x883e13=_0x526707;super(),this[_0x883e13(0x31d)]();}[_0x526707(0x171)](){const _0x31029b=_0x526707;return this[_0x31029b(0x134)];}[_0x526707(0x31d)](){const _0x1833fe=_0x526707;this[_0x1833fe(0x134)]=[],this['setTitle'](''),this[_0x1833fe(0x158)](NaN,NaN);}['createTitle'](){const _0x4a7f02=_0x526707;if(this['_title'])return this[_0x4a7f02(0x20d)];for(const _0x18ad25 of this[_0x4a7f02(0x134)]){const _0x144d69=_0x18ad25[_0x4a7f02(0x1fc)]();if(_0x144d69)return _0x144d69;}return _0x4a7f02(0x205);}[_0x526707(0x218)](_0x38a36d){const _0x5fc3e=_0x526707;this[_0x5fc3e(0x20d)]=_0x38a36d;}['setLocation'](_0x53b030,_0x4e9bd1){const _0x4771af=_0x526707;this['_mapId']=_0x53b030,this[_0x4771af(0x234)]=_0x4e9bd1;}['mapId'](){const _0x52c8eb=_0x526707;return this[_0x52c8eb(0x313)];}['eventId'](){return this['_eventId'];}[_0x526707(0x21c)](){const _0x5b1854=_0x526707;return this[_0x5b1854(0x134)][_0x5b1854(0x17f)]<=0x0;}[_0x526707(0x27d)](){}['createMinimize'](){const _0xe450a4=_0x526707,_0x3bc222=this['lastItem'](),_0x1854b1=new _0x36c076();return _0x1854b1[_0xe450a4(0x139)](_0x3bc222),_0x1854b1;}[_0x526707(0x29c)](){const _0x4926b7=_0x526707;;const _0x21edfd=this[_0x4926b7(0x23a)](),_0x175577=this['_list'][_0x21edfd];return _0x175577?_0x175577:null;}[_0x526707(0x139)](_0x33ba54){const _0x41574d=_0x526707;this[_0x41574d(0x134)][_0x41574d(0x1f2)](_0x33ba54);}}class _0xe35025{[_0x526707(0x2c9)](){return![];}[_0x526707(0x287)](){}['x'](){return 0x0;}['y'](){return 0x0;}['width'](){return 0x0;}[_0x526707(0x1fb)](){return 0x0;}[_0x526707(0x1c9)](){return 0x0;}[_0x526707(0x33b)](){return null;}[_0x526707(0x14e)](){return null;}[_0x526707(0x282)](){return null;}}class _0x605935{[_0x526707(0x259)](){return null;}[_0x526707(0x215)](){return![];}[_0x526707(0x240)](){}}class _0x5372d5{constructor(_0x18b952){const _0x53da3a=_0x526707;this[_0x53da3a(0x177)]=_0x18b952,this[_0x53da3a(0x331)](null);}[_0x526707(0x1b1)](){const _0x378adf=_0x526707;return this[_0x378adf(0x177)][_0x378adf(0x36e)]();}[_0x526707(0x331)](_0x5214f1){const _0x1ab06c=_0x526707;this[_0x1ab06c(0x298)]=_0x5214f1;}[_0x526707(0x26e)](_0xed7978,_0x1726ef){const _0x549ebf=_0x526707;this[_0x549ebf(0x298)]&&!!_0x1726ef?this[_0x549ebf(0x298)](_0xed7978,_0x1726ef):AudioManager[_0x549ebf(0x149)](_0xed7978);}[_0x526707(0x2f4)](){const _0xba7381=_0x526707;return this['_logManager']['getLogItemStyle']()[_0xba7381(0x244)];}[_0x526707(0x2b9)](_0x420dba){const _0x265fab=_0x526707;return this[_0x265fab(0x177)][_0x265fab(0x2b9)](_0x420dba);}['setLastVoiceParam'](_0x5c0a20,_0xc5dd41){const _0xbfe7cf=_0x526707;this[_0xbfe7cf(0x177)][_0xbfe7cf(0x252)](_0x5c0a20,_0xc5dd41);}[_0x526707(0x2c0)](_0x15ccd8){const _0x5d7be6=_0x526707;this['_logManager'][_0x5d7be6(0x2c0)](_0x15ccd8);}[_0x526707(0x2a6)](){const _0x4ce737=_0x526707;return this['_logManager'][_0x4ce737(0x2a6)]();}}class _0x5e625b extends Sprite_Clickable{constructor(_0x5dd88c){const _0x5265cf=_0x526707;super();const _0xa115f6=_0x5dd88c[_0x5265cf(0x259)]();this[_0x5265cf(0x140)]=_0x5dd88c,this[_0x5265cf(0x282)]=_0xa115f6[_0x5265cf(0x282)]();const _0x1e3666=_0xa115f6[_0x5265cf(0x33b)]();this[_0x5265cf(0x2b2)](_0x1e3666['x'],_0x1e3666['y'],_0x1e3666[_0x5265cf(0x2e7)],_0x1e3666['height']);const _0x2dd8fa=_0xa115f6[_0x5265cf(0x14e)]();this['setColdFrame'](_0x2dd8fa['x'],_0x2dd8fa['y'],_0x2dd8fa['width'],_0x2dd8fa[_0x5265cf(0x1fb)]),this[_0x5265cf(0x390)](),this['x']=_0xa115f6['x'](),this['y']=_0xa115f6['y'](),this['_pressed']=![],this['_hovered']=![];}[_0x526707(0x1a8)](_0x509b2c){}get[_0x526707(0x1fb)](){const _0x332161=_0x526707;return Math[_0x332161(0x358)](this[_0x332161(0x29b)]['height'],this[_0x332161(0x1b7)][_0x332161(0x1fb)]);}get[_0x526707(0x2e7)](){const _0x47a16b=_0x526707;return Math[_0x47a16b(0x358)](this[_0x47a16b(0x29b)]['width'],this[_0x47a16b(0x1b7)][_0x47a16b(0x2e7)]);}[_0x526707(0x2e0)](){const _0x4671ce=_0x526707;super['update'](),this[_0x4671ce(0x319)](),this[_0x4671ce(0x390)]();}[_0x526707(0x2b2)](_0xe21045,_0x4da672,_0x5c9620,_0x217a6b){const _0x21c72b=_0x526707;this[_0x21c72b(0x29b)]=new Rectangle(_0xe21045,_0x4da672,_0x5c9620,_0x217a6b);}[_0x526707(0x38d)](_0x28e464,_0x1666ef,_0x1afe8a,_0x39c2f7){this['_coldFrame']=new Rectangle(_0x28e464,_0x1666ef,_0x1afe8a,_0x39c2f7);}[_0x526707(0x184)](){return this['isPressed']();}[_0x526707(0x390)](){const _0x377115=_0x526707,_0x58a1fd=this[_0x377115(0x184)]()?this[_0x377115(0x29b)]:this[_0x377115(0x1b7)];_0x58a1fd&&this['setFrame'](_0x58a1fd['x'],_0x58a1fd['y'],_0x58a1fd['width'],_0x58a1fd[_0x377115(0x1fb)]);}[_0x526707(0x17c)](){const _0xb9f578=_0x526707;if(this[_0xb9f578(0x1bb)]){if(!this[_0xb9f578(0x1bb)][_0xb9f578(0x2ba)])return![];}return this[_0xb9f578(0x2ba)]&&this[_0xb9f578(0x140)][_0xb9f578(0x215)]();}[_0x526707(0x240)](){const _0x44cc38=_0x526707;this['isClickEnabled']()&&this[_0x44cc38(0x140)][_0x44cc38(0x240)]();}[_0x526707(0x20e)](){const _0x838115=_0x526707;this[_0x838115(0x2ba)]=this[_0x838115(0x140)][_0x838115(0x215)]();}}class _0x47c341{[_0x526707(0x288)](_0x4b27e3,_0x54e2b3){}['createButtonSprite'](_0x312d20){return null;}['createOnOffButtonSprite'](_0x3d23fb){return null;}[_0x526707(0x208)](_0x1deacc){}[_0x526707(0x24c)](){}['quickLoad'](){}
    }const _0x3b171d=_0x526707(0x30d);function _0x39e078(){const _0x25f716=_0x526707,_0x4884b0=decodeURIComponent(document['currentScript'][_0x25f716(0x28b)])[_0x25f716(0x30b)](/([^/]+)\.js$/);if(_0x4884b0)return _0x4884b0[0x1];return'';}function _0x488d09(_0x4a760f){const _0x2e43ee=_0x526707,_0x306a00=_0x39e078();if(_0x4a760f===_0x306a00)return;const _0x402c9b='Do\x20not\x20rename\x20the\x20plugin\x20file.<br>'+(_0x2e43ee(0x1a9)+_0x306a00+_0x2e43ee(0x286))+(_0x2e43ee(0x2d5)+_0x4a760f+_0x2e43ee(0x286))+_0x2e43ee(0x2a2)+(_0x2e43ee(0x1d2)+_0x306a00+'<br>')+('本来のファイル名:\x20'+_0x4a760f);throw new Error(_0x402c9b);}_0x488d09(_0x3b171d);class _0x428bdc extends _0x47c341{[_0x526707(0x288)](_0x408316,_0x15dfb5){const _0x58c03e=_0x526707;_0x408316[_0x58c03e(0x288)](_0x15dfb5);}['createButtonSprite'](_0x3f1409){return new _0x5e625b(_0x3f1409);}['createOnOffButtonSprite'](_0x79b97a){return new _0x178aa4(_0x79b97a);}[_0x526707(0x24c)](){const _0x59fcce=_0x526707,_0x44c7e3=_0x3455ea[_0x59fcce(0x239)]()['quickSaveFileName'](),_0x50c286=DataManager['makeSaveContents']();return StorageManager[_0x59fcce(0x328)](_0x44c7e3,_0x50c286);}[_0x526707(0x22f)](){const _0x2ec46c=_0x526707,_0x539da0=_0x3455ea[_0x2ec46c(0x239)]()[_0x2ec46c(0x1cf)]();return StorageManager[_0x2ec46c(0x2f8)](_0x539da0)['then'](_0x39ffea=>{const _0x4e24ac=_0x2ec46c;return DataManager[_0x4e24ac(0x1bf)](),DataManager[_0x4e24ac(0x33e)](_0x39ffea),DataManager[_0x4e24ac(0x154)](),0x0;});}}function _0x31b32d(_0x3f9439,_0x2b6b60,_0x2312ac){const _0x567041=_0x526707;if(Utils['RPGMAKER_NAME']==='MZ'){_0x2312ac[_0x567041(0x17b)](_0x3f9439,_0x2b6b60);return;}if(Utils[_0x567041(0x1a4)]==='MV'){_0x2312ac[_0x567041(0x17b)](_0x3f9439,_0x2b6b60['x'],_0x2b6b60['y'],_0x2b6b60['width'],_0x2b6b60[_0x567041(0x1fb)]);return;}throw new Error('Unknow\x20RPG\x20MAKER:'+Utils[_0x567041(0x1a4)]);}class _0xd178b1{constructor(_0xb6b32c,_0x56bf54,_0x4ebbd5,_0x544007){const _0x45fd37=_0x526707;this[_0x45fd37(0x254)]=_0xb6b32c,this['_volume']=_0x56bf54,this[_0x45fd37(0x15e)]=_0x4ebbd5,this[_0x45fd37(0x2ff)]=_0x544007;}static[_0x526707(0x326)](_0x13837a){const _0x1a92a2=_0x526707;if(!_0x13837a)return null;const _0x2989bb=JSON['parse'](_0x13837a),_0x2fef95=_0x2989bb['name'],_0x17725c=Number(_0x2989bb['volume']),_0x5f3e5c=Number(_0x2989bb['pitch']),_0x131ade=Number(_0x2989bb[_0x1a92a2(0x37e)]);return new _0xd178b1(_0x2fef95,_0x17725c,_0x5f3e5c,_0x131ade);}[_0x526707(0x2e6)](){const _0x1ac9bb=_0x526707;if(this[_0x1ac9bb(0x254)]){const _0x1ab0d7={'pos':0x0,'name':this[_0x1ac9bb(0x254)],'volume':this[_0x1ac9bb(0x37d)],'pitch':this[_0x1ac9bb(0x15e)],'pan':this['_pan']};AudioManager[_0x1ac9bb(0x149)](_0x1ab0d7);}}}function _0x3c99d0(_0x205ea3){const _0x2771c8=_0x526707,_0x286c94=JSON[_0x2771c8(0x2f3)](_0x205ea3);return new Rectangle(Number(_0x286c94['x']),Number(_0x286c94['y']),Number(_0x286c94['width']),Number(_0x286c94[_0x2771c8(0x1fb)]));}class _0x49a9f6 extends _0xe35025{constructor(_0x457543,_0x3cd030,_0x55faac,_0x106f20,_0x37838e,_0x50b561,_0x2ab4ef){const _0x694127=_0x526707;super(),this[_0x694127(0x254)]=_0x457543,this[_0x694127(0x29b)]=_0x106f20,this['_coldFrame']=_0x37838e,this['_x']=_0x3cd030,this['_y']=_0x55faac,this['_switchId']=_0x50b561,this[_0x694127(0x394)]=_0x2ab4ef;}static[_0x526707(0x326)](_0x122514){const _0xaabca0=_0x526707,_0x1017f3=JSON[_0xaabca0(0x2f3)](_0x122514),_0x23bf3a=_0xd178b1[_0xaabca0(0x326)](_0x1017f3[_0xaabca0(0x329)]),_0x2859c2=_0x3c99d0(_0x1017f3[_0xaabca0(0x2f2)]),_0x2fcee7=_0x3c99d0(_0x1017f3[_0xaabca0(0x2a3)]),_0x32d1f0=Number(_0x1017f3['x']),_0x20ace0=Number(_0x1017f3['y']),_0x5d291a=Number(_0x1017f3['enabledSwitch']||0x0);return new _0x49a9f6(_0x1017f3['image'],_0x32d1f0,_0x20ace0,_0x2859c2,_0x2fcee7,_0x5d291a,_0x23bf3a);}['isValid'](){const _0x56415a=_0x526707;return!!this[_0x56415a(0x254)];}[_0x526707(0x1c9)](){return this['_switchId'];}[_0x526707(0x282)](){const _0x4e6d95=_0x526707;return ImageManager[_0x4e6d95(0x1e4)](this[_0x4e6d95(0x254)]);}[_0x526707(0x287)](){const _0x218644=_0x526707;this[_0x218644(0x394)]&&this['_se'][_0x218644(0x2e6)]();}[_0x526707(0x14e)](){const _0x1a9af9=_0x526707;return this[_0x1a9af9(0x1b7)][_0x1a9af9(0x21d)]();}['hotFrame'](){const _0x19b653=_0x526707;return this[_0x19b653(0x29b)][_0x19b653(0x21d)]();}['x'](){return this['_x'];}['y'](){return this['_y'];}[_0x526707(0x2e7)](){const _0x13a491=_0x526707;return Math[_0x13a491(0x358)](this[_0x13a491(0x29b)]['width'],this[_0x13a491(0x1b7)][_0x13a491(0x2e7)]);}[_0x526707(0x1fb)](){const _0x474d7f=_0x526707;return Math[_0x474d7f(0x358)](this[_0x474d7f(0x29b)][_0x474d7f(0x1fb)],this[_0x474d7f(0x1b7)]['height']);}}class _0x27f83b extends _0x605935{constructor(_0x2deb4f,_0xfb7881){const _0x4d4781=_0x526707;super(),this['_layout']=_0x2deb4f,this[_0x4d4781(0x147)]=_0xfb7881;}[_0x526707(0x2c9)](){const _0x3ff794=_0x526707;return this[_0x3ff794(0x1ee)]&&this[_0x3ff794(0x1ee)][_0x3ff794(0x2c9)]();}['layout'](){const _0x1fabc1=_0x526707;return this[_0x1fabc1(0x1ee)];}[_0x526707(0x215)](){const _0x2079c6=_0x526707,_0x1f0202=this[_0x2079c6(0x1ee)][_0x2079c6(0x1c9)]();if(_0x1f0202)return $gameSwitches[_0x2079c6(0x170)](_0x1f0202);return!![];}[_0x526707(0x386)](){return this['_symbol'];}[_0x526707(0x17e)](){const _0x58f494=_0x526707;this[_0x58f494(0x147)]&&this[_0x58f494(0x24f)]()&&this[_0x58f494(0x240)]();}['isTriggered'](){const _0x48e055=_0x526707;return Input[_0x48e055(0x19c)](this['_symbol']);}[_0x526707(0x308)](){}[_0x526707(0x240)](){const _0x47a01f=_0x526707;this[_0x47a01f(0x1ee)][_0x47a01f(0x287)](),this['callOkHandler']();}[_0x526707(0x2c6)](){const _0x110809=_0x526707;return this['logManager']()['getWorkaround']()[_0x110809(0x207)](this);}[_0x526707(0x209)](){return _0x3455ea;}[_0x526707(0x1d6)](_0x9ba8b9){const _0x257468=_0x526707;this[_0x257468(0x209)]()[_0x257468(0x1d6)](_0x9ba8b9);}}class _0x38e254 extends _0x27f83b{[_0x526707(0x308)](){const _0x46b33c=_0x526707;this[_0x46b33c(0x1d6)](_0x24fdf8);}[_0x526707(0x24f)](){const _0x440539=_0x526707;return super[_0x440539(0x24f)]()||TouchInput[_0x440539(0x30a)]<0x0;}}class _0x75685d extends _0x27f83b{[_0x526707(0x308)](){const _0x59852b=_0x526707;this[_0x59852b(0x1d6)](Scene_Load);}}class _0x4c7a58 extends _0x27f83b{[_0x526707(0x215)](){return super['isEnabled']()&&this['logManager']()['canSave']();}['callOkHandler'](){this['pushScene'](Scene_Save);}}class _0x176773 extends _0x27f83b{[_0x526707(0x215)](){const _0x2bc015=_0x526707;return super[_0x2bc015(0x215)]()&&this[_0x2bc015(0x209)]()[_0x2bc015(0x21e)]();}['callOkHandler'](){const _0x47f74a=_0x526707;this[_0x47f74a(0x209)]()[_0x47f74a(0x30f)]()[_0x47f74a(0x24c)]();}[_0x526707(0x33c)](){}[_0x526707(0x223)](){}}class _0x465eef extends _0x27f83b{['callOkHandler'](){const _0x5ba488=_0x526707,_0x49cbd7=DataManager[_0x5ba488(0x38a)](0x0);_0x49cbd7&&SceneManager[_0x5ba488(0x2fd)](Scene_Map);}}class _0x292295 extends _0x27f83b{[_0x526707(0x2c6)](){const _0x1a78f2=_0x526707;return this[_0x1a78f2(0x209)]()[_0x1a78f2(0x30f)]()['createOnOffButtonSprite'](this);}['isButtonOn'](){return![];}}class _0x178aa4 extends _0x5e625b{constructor(_0x25d88b){
        const _0x5e578a=_0x526707;super(_0x25d88b),this[_0x5e578a(0x1a1)]=_0x25d88b;}['onClick'](){const _0x37409a=_0x526707;super[_0x37409a(0x240)](),this[_0x37409a(0x390)]();}[_0x526707(0x184)](){const _0x1b7093=_0x526707;return this[_0x1b7093(0x1a1)]&&this[_0x1b7093(0x1a1)][_0x1b7093(0x150)]();}}class _0x425e2d extends _0x178aa4{constructor(_0x307354){const _0x41319f=_0x526707;super(_0x307354),this[_0x41319f(0x24e)]=null;}['startMessage'](){const _0x3d5a2d=_0x526707;super['startMessage'](),this['updateFrame'](),this[_0x3d5a2d(0x24e)]&&this[_0x3d5a2d(0x24e)][_0x3d5a2d(0x195)](0x0);}[_0x526707(0x201)](_0x5f3dc4){const _0x403f72=_0x526707;this[_0x403f72(0x24e)]&&this[_0x403f72(0x33a)](this[_0x403f72(0x24e)]),this['_gauge']=_0x5f3dc4,this[_0x403f72(0x350)](_0x5f3dc4);}[_0x526707(0x2e0)](){const _0x2f3d0e=_0x526707;super['update'](),this[_0x2f3d0e(0x24e)]&&!this[_0x2f3d0e(0x24e)][_0x2f3d0e(0x2e0)]&&this[_0x2f3d0e(0x24e)]['setValue'](_0x3455ea[_0x2f3d0e(0x34f)]());}}class _0x1df67e extends _0x292295{constructor(_0x2d67f8,_0x2e79f4,_0x4b63d1){super(_0x2e79f4,_0x4b63d1),this['_gauge']=_0x2d67f8;}['callOkHandler'](){const _0xb54b42=_0x526707;this[_0xb54b42(0x209)]()[_0xb54b42(0x2ae)]();}[_0x526707(0x150)](){const _0x2c493d=_0x526707;return this[_0x2c493d(0x209)]()[_0x2c493d(0x321)]();}[_0x526707(0x2c6)](){const _0x52a5d3=_0x526707,_0x3a093f=new _0x425e2d(this);if(this[_0x52a5d3(0x24e)]&&this['_gauge']['isVisible']()){const _0x1b2c96=this[_0x52a5d3(0x24e)][_0x52a5d3(0x2c6)](this[_0x52a5d3(0x1ee)][_0x52a5d3(0x2e7)]()/0x2);_0x1b2c96&&_0x3a093f[_0x52a5d3(0x201)](_0x1b2c96);}return _0x3a093f;}}class _0x5bfc81 extends _0x292295{constructor(_0x4151ce,_0x5a0583,_0x56af57){const _0x3a0599=_0x526707;super(_0x5a0583,_0x56af57),this[_0x3a0599(0x227)]=_0x4151ce;}[_0x526707(0x150)](){const _0x695108=_0x526707;return $gameSwitches['value'](this[_0x695108(0x227)]);}[_0x526707(0x308)](){const _0x43777a=_0x526707,_0x54d067=$gameSwitches['value'](this[_0x43777a(0x227)]);$gameSwitches[_0x43777a(0x195)](this[_0x43777a(0x227)],!_0x54d067);}[_0x526707(0x17e)](){const _0xbad6ac=_0x526707;super[_0xbad6ac(0x17e)]();}}function _0x362015(_0xb3e965){const _0x5862ae=_0x526707,_0x2b69f6=/^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$/[_0x5862ae(0x16b)](_0xb3e965);if(_0x2b69f6){const _0x42a104=Number('0x'+_0xb3e965);if(!isNaN(_0x42a104))return _0x42a104;}return 0x0;}function _0x491158(){}class _0x32bcf8{constructor(_0x4991d2,_0x1c8bbc,_0x251efc,_0x46a49f,_0x3aeca7,_0x379db0){const _0x359829=_0x526707;this[_0x359829(0x172)]=_0x251efc,this[_0x359829(0x148)]=_0x46a49f,this[_0x359829(0x2d3)]=_0x379db0,this[_0x359829(0x35f)]=_0x3aeca7,this['_x']=_0x4991d2,this['_y']=_0x1c8bbc;}static['create'](_0xb8e9e3){const _0x13158e=_0x526707,_0x4baa3e=JSON[_0x13158e(0x2f3)](_0xb8e9e3),_0x5b8d8a=Number(_0x4baa3e['x']||0x0),_0x490dd9=Number(_0x4baa3e['y']||0x0),_0x566abe=String(_0x4baa3e['gaugeType']),_0x3bc8d1=Number(_0x4baa3e[_0x13158e(0x2e7)]),_0x2eda69=_0x362015(_0x4baa3e[_0x13158e(0x30c)]),_0x383b24=String(_0x4baa3e[_0x13158e(0x2df)]||'');return new _0x32bcf8(_0x5b8d8a,_0x490dd9,_0x3bc8d1,_0x383b24,_0x2eda69,_0x566abe);}['isVisible'](){const _0x8e8d17=_0x526707;return this[_0x8e8d17(0x2d3)];}[_0x526707(0x335)](){const _0x399546=_0x526707;return ImageManager[_0x399546(0x1e4)](this[_0x399546(0x148)]);}[_0x526707(0x2e7)](){return this['_width'];}[_0x526707(0x30c)](){const _0x57c188=_0x526707;return _0x3455ea[_0x57c188(0x239)]()[_0x57c188(0x284)]();}['createSpriteWithType'](){const _0x44543c=_0x526707;if(this[_0x44543c(0x2d3)]===_0x44543c(0x1b3))return null;}['createSprite'](_0x4baf26){const _0x11f673=_0x526707;if(this[_0x11f673(0x2d3)]===_0x11f673(0x1b3))return null;const _0x2e8ffa=new _0x16fd27(_0x4baf26);_0x2e8ffa['x']=this['_x'],_0x2e8ffa['y']=this['_y'];if(this[_0x11f673(0x148)]){const _0x4f7ea6=this[_0x11f673(0x335)]();_0x2e8ffa[_0x11f673(0x2fe)](_0x4f7ea6,this[_0x11f673(0x172)],this[_0x11f673(0x30c)]());}else _0x2e8ffa['lineStyle'](this['_width'],this['color']());return _0x2e8ffa;}}class _0x10ad5f extends _0x27f83b{[_0x526707(0x308)](){const _0x1da867=_0x526707;this['logManager']()[_0x1da867(0x183)]();}[_0x526707(0x215)](){const _0x3033e5=_0x526707;return this[_0x3033e5(0x209)]()[_0x3033e5(0x35b)]();}['isTriggered'](){const _0x5e6a9f=_0x526707,_0x38b574=this['symbol']();return _0x38b574&&Input[_0x5e6a9f(0x24f)](_0x38b574);}}class _0x40f0cf extends _0x27f83b{[_0x526707(0x308)](){const _0x23b405=_0x526707;this['logManager']()[_0x23b405(0x35a)]();}}class _0x2377f2{constructor(_0x3c9c8b,_0x3cafac,_0x5f3962,_0x1ef975,_0xefebc6,_0x21b14f){const _0x440aa6=_0x526707;this[_0x440aa6(0x134)]=_0x3c9c8b,this['_offsetX']=_0x3cafac,this[_0x440aa6(0x32d)]=_0x5f3962,this[_0x440aa6(0x35d)]=_0x1ef975,this['_windowStretchY']=_0x21b14f,this[_0x440aa6(0x38c)]=_0xefebc6;}static[_0x526707(0x326)](_0x4a4de7,_0x12741c){const _0x20c61a=_0x526707;if(_0x4a4de7){const _0x4d0fdc=JSON['parse'](_0x4a4de7),_0x22aa8b=Number(_0x4d0fdc[_0x20c61a(0x38e)]),_0x11e8d6=Number(_0x4d0fdc[_0x20c61a(0x2ac)]),_0x223d29=_0x4d0fdc[_0x20c61a(0x151)],_0x173f02=Number(_0x4d0fdc[_0x20c61a(0x1d4)]),_0x4b70f7=Number(_0x4d0fdc[_0x20c61a(0x332)]||0x0);return new _0x2377f2(_0x12741c,_0x22aa8b,_0x11e8d6,_0x223d29,_0x4b70f7,_0x173f02);}return new _0x2377f2(_0x12741c,0x0,0x0,_0x20c61a(0x1e0),0x0,0x0);}['isButtonDisabled'](){const _0x4934f2=_0x526707;return $gameSwitches['value'](this[_0x4934f2(0x38c)]);}[_0x526707(0x28f)](){const _0xca87b5=_0x526707;return this[_0xca87b5(0x134)][_0xca87b5(0x264)](_0x324552=>{return _0x324552['createSprite']();});}[_0x526707(0x15a)](){const _0x18ad73=_0x526707;for(const _0x2d3b94 of this['_list']){$gameSwitches[_0x18ad73(0x195)](_0x2d3b94[_0x18ad73(0x259)]()[_0x18ad73(0x1c9)](),!![]);}}['updateInput'](){const _0x5cb783=_0x526707;if(this['isButtonDisabled']())return;for(const _0x2859b7 of this[_0x5cb783(0x134)]){if(SceneManager[_0x5cb783(0x18b)]())return;_0x2859b7[_0x5cb783(0x17e)]();}}[_0x526707(0x38e)](){const _0x4d487b=_0x526707;return this[_0x4d487b(0x15c)];}[_0x526707(0x2ac)](){const _0x2b7b0f=_0x526707;return this[_0x2b7b0f(0x32d)];}[_0x526707(0x249)](){const _0x2112c=_0x526707;return this[_0x2112c(0x35d)]===_0x2112c(0x1e0);}[_0x526707(0x238)](){const _0x11ce56=_0x526707;return this[_0x11ce56(0x35d)]===_0x11ce56(0x1f1);}['createOutside'](){return new _0x1a5366(this);}}class _0x4c5490{constructor(_0x2953b7,_0x4b3dbb){const _0x3052b5=_0x526707;this[_0x3052b5(0x276)]=new RegExp('^'+_0x2953b7+'.+'),this[_0x3052b5(0x339)]=new Set(_0x4b3dbb);}static[_0x526707(0x326)](_0x4fbb52){const _0x2918bf=_0x526707,_0x517607=JSON['parse'](_0x4fbb52),_0x5665e2=_0x517607[_0x2918bf(0x236)],_0x5568c3=JSON['parse'](_0x517607[_0x2918bf(0x16e)]);return new _0x4c5490(_0x5665e2,_0x5568c3);}[_0x526707(0x1d7)](_0x18a8dc){const _0x5cd12e=_0x526707;if(this[_0x5cd12e(0x276)][_0x5cd12e(0x380)](_0x18a8dc))return!![];return this[_0x5cd12e(0x339)][_0x5cd12e(0x16d)](_0x18a8dc);}}class _0x5304c3{constructor(_0x1c6ae6){const _0x27ec94=_0x526707;this[_0x27ec94(0x134)]=_0x1c6ae6,this[_0x27ec94(0x20d)]=_0x1c6ae6['createTitle'](),this['_cache']=null;}['makeCache'](){const _0x29e3f0=_0x526707;!this[_0x29e3f0(0x156)]&&(this[_0x29e3f0(0x156)]=this[_0x29e3f0(0x134)]['createProxy']());}['title'](){const _0x5a4388=_0x526707;return this[_0x5a4388(0x20d)];}['multiLineItems'](){const _0x31bf63=_0x526707;if(this[_0x31bf63(0x156)])return this['_cache'];return[];}[_0x526707(0x346)](){const _0x5d43d2=_0x526707;return!this[_0x5d43d2(0x134)][_0x5d43d2(0x21c)]();}}class _0x44bdad extends Window_Selectable{constructor(_0x3480b7){const _0x2bbd87=_0x526707;super(_0x3480b7),this[_0x2bbd87(0x2ef)](null),this['setList']([]);}['setList'](_0x59d8f4){const _0x16d350=_0x526707;this[_0x16d350(0x134)]=_0x59d8f4['map'](_0x1be2dc=>new _0x5304c3(_0x1be2dc)),this[_0x16d350(0x374)]();}[_0x526707(0x21f)](){const _0x437903=_0x526707;return this[_0x437903(0x134)][_0x437903(0x17f)];}[_0x526707(0x1c4)](_0x5abc86){const _0x28d3a1=_0x526707,_0x224c3f=this[_0x28d3a1(0x28d)](_0x5abc86);if(_0x224c3f){const _0x23f33a=this[_0x28d3a1(0x166)](_0x5abc86);this[_0x28d3a1(0x18e)](_0x224c3f[_0x28d3a1(0x2e2)](),_0x23f33a['x'],_0x23f33a['y'],_0x23f33a[_0x28d3a1(0x2e7)]);}}[_0x526707(0x2d6)](){const _0x4e3b21=_0x526707;super[_0x4e3b21(0x2d6)]();if(this[_0x4e3b21(0x256)]){const _0x4fdf05=this[_0x4e3b21(0x2b3)]();_0x4fdf05?(_0x4fdf05[_0x4e3b21(0x301)](),this[_0x4e3b21(0x256)][_0x4e3b21(0x35e)](_0x4fdf05['multiLineItems']())):this[_0x4e3b21(0x256)][_0x4e3b21(0x35e)]([]);}}[_0x526707(0x2ef)](_0x478e78){const _0x29b651=_0x526707;this[_0x29b651(0x256)]=_0x478e78;}['itemAt'](_0x14a787){const _0x426130=_0x526707;return this[_0x426130(0x134)][_0x14a787];}[_0x526707(0x2b3)](){
            const _0x505f16=_0x526707;return this[_0x505f16(0x28d)](this[_0x505f16(0x31a)]());}[_0x526707(0x1c6)](){const _0x1b3586=_0x526707,_0x5db6f1=this[_0x1b3586(0x2b3)]();if(_0x5db6f1&&_0x5db6f1[_0x1b3586(0x346)]())return!![];return![];}[_0x526707(0x199)](){const _0x35f6a3=_0x526707,_0x27ef93=this[_0x35f6a3(0x21f)]();_0x3455ea['getWorkaround']()['forceSelect'](this,_0x27ef93-0x1);}}class _0x1012e1 extends Window_Selectable{[_0x526707(0x22a)](_0x5d824a){const _0x152af5=_0x526707;_0x31b32d(this,_0x5d824a,super[_0x152af5(0x22a)]);}[_0x526707(0x340)](_0x2ceec0){return 0x1;}[_0x526707(0x29a)](_0x33a9e1){return'';}[_0x526707(0x222)](_0x16da95){return _0x16da95;}[_0x526707(0x2ea)](_0x2a6e1d){const _0x5794d5=_0x526707,_0x213be2=this[_0x5794d5(0x222)](_0x2a6e1d),_0x151be0=this[_0x5794d5(0x340)](_0x2a6e1d);return _0x213be2+_0x151be0-0x1;}[_0x526707(0x1ef)](){const _0x464c61=_0x526707;return'index:'+this[_0x464c61(0x31a)]()+_0x464c61(0x19f)+this['_scrollY'];}[_0x526707(0x1e3)](){const _0x1f3011=_0x526707;this[_0x1f3011(0x241)]['setText'](this[_0x1f3011(0x1ef)]());}['baseRect'](_0x5ca52d){const _0x59c37d=_0x526707;return super[_0x59c37d(0x2fa)](_0x5ca52d);}['nextTopIndex'](){const _0x18808c=_0x526707,_0x26ba1c=Math['max'](0x0,this[_0x18808c(0x31a)]()),_0x54bfad=this[_0x18808c(0x222)](_0x26ba1c),_0x46e4ed=this['maxItems'](),_0x430c38=(_0x54bfad+_0x46e4ed-0x1)%_0x46e4ed,_0x290e31=this[_0x18808c(0x222)](_0x430c38);if(_0x290e31>_0x26ba1c)return this[_0x18808c(0x2ea)](_0x290e31);return _0x290e31;}['cursorUp'](_0x47625d){const _0x34341c=_0x526707,_0x50b7e4=this[_0x34341c(0x2c1)]();this[_0x34341c(0x2e8)](_0x50b7e4);}[_0x526707(0x145)](){const _0x38b05a=_0x526707,_0x5625c0=Math[_0x38b05a(0x358)](0x0,this['index']()),_0x4bb767=this[_0x38b05a(0x2ea)](_0x5625c0),_0x1f005f=this[_0x38b05a(0x21f)](),_0x268022=(_0x4bb767+_0x1f005f+0x1)%_0x1f005f,_0x3d7804=this['bottomItemIndex'](_0x268022);if(_0x3d7804>_0x5625c0)return _0x3d7804;return this[_0x38b05a(0x222)](_0x3d7804);}['cursorDown'](_0x101a8e){const _0x4ddf7d=_0x526707,_0x5d5d0c=this[_0x4ddf7d(0x145)]();this['smoothSelect'](_0x5d5d0c);}[_0x526707(0x22d)](){const _0x3ac768=_0x526707;return this[_0x3ac768(0x224)]();}[_0x526707(0x348)](){const _0x244b25=_0x526707,_0x50850b=this[_0x244b25(0x224)](),_0x4a7f36=this[_0x244b25(0x34e)]();return _0x50850b+_0x4a7f36;}[_0x526707(0x1a6)](_0x5de440){const _0x5dd485=_0x526707,_0x315ad8=this[_0x5dd485(0x1aa)](),_0x3b76cf=this[_0x5dd485(0x34d)]()*0x2;return(_0x315ad8+_0x3b76cf)*_0x5de440;}[_0x526707(0x2fa)](_0x2cd427){const _0x47f930=_0x526707,_0x25bf3a=this['topItemIndex'](_0x2cd427),_0xe8a7bf=this[_0x47f930(0x13a)](_0x25bf3a),_0xa21edd=this[_0x47f930(0x340)](_0x25bf3a),_0x4e096b=this[_0x47f930(0x1a6)](_0xa21edd-0x1);return _0xe8a7bf[_0x47f930(0x1fb)]+=_0x4e096b,_0xe8a7bf;}[_0x526707(0x27b)](_0x2735c8){const _0x1b5e68=_0x526707,_0x2f1c27=this[_0x1b5e68(0x13a)](_0x2735c8),_0x459ed4=this[_0x1b5e68(0x389)]();return _0x2f1c27['x']+=_0x459ed4,_0x2f1c27['width']-=_0x459ed4*0x2,_0x2f1c27;}[_0x526707(0x363)](_0x32c581){const _0x3fc8e8=_0x526707,_0x1f398b=this[_0x3fc8e8(0x222)](_0x32c581);return _0x1f398b===_0x32c581;}['drawItemBackground'](_0x4e4b81){const _0x51f81e=_0x526707;this[_0x51f81e(0x363)](_0x4e4b81)&&super[_0x51f81e(0x2d0)](_0x4e4b81);}['drawItem'](_0x128c4c){const _0x9f51c9=_0x526707,_0x1c318b=this[_0x9f51c9(0x29a)](_0x128c4c);if(_0x1c318b){const _0x5b840f=this[_0x9f51c9(0x27b)](_0x128c4c);this[_0x9f51c9(0x18e)](_0x1c318b,_0x5b840f['x'],_0x5b840f['y'],_0x5b840f[_0x9f51c9(0x2e7)]);}}}class _0x326c20 extends _0x1012e1{[_0x526707(0x35e)](_0x229388){const _0x443b05=_0x526707;this[_0x443b05(0x134)]=_0x229388;}[_0x526707(0x31d)](){const _0x650206=_0x526707;this[_0x650206(0x35e)]([]);}['maxItems'](){return this['_list']['length'];}[_0x526707(0x28d)](_0x2535f1){const _0x4570a9=_0x526707;return this[_0x4570a9(0x134)][_0x2535f1];}[_0x526707(0x2b3)](){return this['itemAt'](this['index']());}[_0x526707(0x222)](_0x411c8c){const _0xb82ef8=_0x526707,_0x5d0e7b=this['itemAt'](_0x411c8c);if(_0x5d0e7b)return _0x411c8c-_0x5d0e7b[_0xb82ef8(0x2a1)]();return _0x411c8c;}[_0x526707(0x363)](_0x804bf0){const _0x321c47=_0x526707,_0x5b97b7=this[_0x321c47(0x28d)](_0x804bf0);if(_0x5b97b7)return _0x5b97b7[_0x321c47(0x363)]();return![];}[_0x526707(0x29a)](_0x4f2990){const _0x3951ea=this['itemAt'](_0x4f2990);if(_0x3951ea)return _0x3951ea['text']();return'';}[_0x526707(0x340)](_0x258593){const _0x375384=_0x526707,_0xd4d9b4=this[_0x375384(0x28d)](_0x258593);if(_0xd4d9b4)return _0xd4d9b4[_0x375384(0x340)]();return 0x1;}[_0x526707(0x34d)](){return 0x0;}['lineSpacing'](){return 0x4;}[_0x526707(0x1aa)](){const _0x4d45ae=_0x526707;return super[_0x4d45ae(0x1aa)]()+this[_0x4d45ae(0x323)]();}['itemHeight'](){const _0x2031f9=_0x526707;return this[_0x2031f9(0x1aa)]();}}class _0x3f3143 extends _0x326c20{[_0x526707(0x22a)](_0x36d6a9){const _0x5d4c62=_0x526707;this[_0x5d4c62(0x19b)]=_0x3455ea[_0x5d4c62(0x25c)]()['logStyle'](),super[_0x5d4c62(0x22a)](_0x36d6a9),this['makeItemList']();}[_0x526707(0x138)](){const _0x14c4d7=_0x526707,_0x148e64=_0x3455ea['readOnryData']()[_0x14c4d7(0x14b)](),_0x5ea501=_0x148e64[_0x14c4d7(0x2f7)]();_0x5ea501?this[_0x14c4d7(0x302)]=_0x5ea501:super[_0x14c4d7(0x138)]();}[_0x526707(0x323)](){const _0x17a777=_0x526707;return this[_0x17a777(0x19b)][_0x17a777(0x316)]()[_0x17a777(0x323)];}[_0x526707(0x226)](){const _0x173221=_0x3455ea['createProxy']();this['setList'](_0x173221);}[_0x526707(0x35e)](_0x1d6da0){const _0x26633b=_0x526707;super[_0x26633b(0x35e)](_0x1d6da0);for(const _0xabeb1 of _0x1d6da0){_0xabeb1&&ImageManager[_0x26633b(0x2db)](_0xabeb1[_0x26633b(0x21b)]());}this[_0x26633b(0x374)]();}[_0x526707(0x29d)](){}[_0x526707(0x352)](){}[_0x526707(0x13c)](){const _0x2f7811=_0x526707,_0x18f8c8=this[_0x2f7811(0x21f)]()-0x1;_0x3455ea[_0x2f7811(0x30f)]()[_0x2f7811(0x288)](this,_0x18f8c8);}[_0x526707(0x146)](){return ImageManager['faceWidth'];}[_0x526707(0x26c)](){const _0x12adbe=_0x526707;return ImageManager[_0x12adbe(0x26c)];}[_0x526707(0x24d)](_0x9cbf14){const _0xc420ab=_0x526707,_0xb46fae=this[_0xc420ab(0x28d)](_0x9cbf14),_0x4510cb=_0xb46fae?_0xb46fae['lineIndex']():0x0,_0xa485d2=this[_0xc420ab(0x13a)](_0x9cbf14-_0x4510cb),_0x1cfb7f=this[_0xc420ab(0x26c)](),_0xb17c80=this['lineSpacing'](),_0x3b47f8=Math['min'](_0xb17c80*0x2,0x4);return _0xa485d2[_0xc420ab(0x2e7)]=this[_0xc420ab(0x146)](),_0xa485d2['height']=_0x1cfb7f,_0xa485d2['x']+=this[_0xc420ab(0x2be)](),_0xa485d2['y']+=_0x3b47f8,_0xa485d2;}[_0x526707(0x378)](_0x1de900){const _0x4bcc74=_0x526707,_0x4fb5d3=this[_0x4bcc74(0x28d)](_0x1de900);if(!_0x4fb5d3['faceName']())return![];if(_0x4fb5d3['isTopItem']())return!![];const _0x3c74bd=this[_0x4bcc74(0x224)]();if(_0x1de900===_0x3c74bd)return!![];return![];}[_0x526707(0x2d4)](_0x4d666d){const _0x1429a3=_0x526707;if(this[_0x1429a3(0x378)](_0x4d666d)){const _0x38ba5d=this[_0x1429a3(0x24d)](_0x4d666d),_0x26b832=this[_0x1429a3(0x28d)](_0x4d666d);this[_0x1429a3(0x2fc)](_0x26b832[_0x1429a3(0x21b)](),_0x26b832[_0x1429a3(0x2f9)](),_0x38ba5d['x'],_0x38ba5d['y'],_0x38ba5d[_0x1429a3(0x2e7)],_0x38ba5d[_0x1429a3(0x1fb)]);}}[_0x526707(0x272)](){const _0x3833c4=_0x526707;return ImageManager[_0x3833c4(0x272)];}[_0x526707(0x258)](_0x105ebd,_0x3ffd8c){const _0x250587=_0x526707,_0x1e2469=_0x105ebd[_0x250587(0x1da)]()?_0x3ffd8c['x']:_0x3ffd8c['x']+_0x3ffd8c[_0x250587(0x2e7)]-this[_0x250587(0x272)]();this[_0x250587(0x376)](this[_0x250587(0x19b)]['voiceIcon'](),_0x1e2469,_0x3ffd8c['y']);}['drawItem'](_0x5f56d3){const _0x524df6=_0x526707;this['callDrawFace'](_0x5f56d3);const _0x3b436f=this['itemAt'](_0x5f56d3);if(!_0x3b436f)return;const _0x3b8937=this[_0x524df6(0x27b)](_0x5f56d3);if(_0x3b436f['needsVoiceIconRender']()){this[_0x524df6(0x258)](_0x3b436f,_0x3b8937);if(_0x3b436f[_0x524df6(0x1da)]()){const _0x497ca5=this['iconWidth']();this[_0x524df6(0x18e)](_0x3b436f[_0x524df6(0x2e4)](),_0x3b8937['x']+_0x497ca5,_0x3b8937['y'],_0x3b8937[_0x524df6(0x2e7)]-_0x497ca5);return;}}super[_0x524df6(0x1c4)](_0x5f56d3);}[_0x526707(0x27b)](_0x2f14d4){const _0x532655=_0x526707,_0xe40f80=super[_0x532655(0x27b)](_0x2f14d4),_0x36aa14=this[_0x532655(0x28d)](_0x2f14d4);if(!!_0x36aa14[_0x532655(0x21b)]()){const _0x2213bc=this[_0x532655(0x146)]();_0xe40f80[_0x532655(0x2e7)]-=_0x2213bc,_0xe40f80['x']+=_0x2213bc+this[_0x532655(0x2be)]();}return _0xe40f80;}}class _0x24a556{constructor(_0x23513d,_0x37e21e,_0x2e8aa6,_0x34fedc,_0xa9753,_0x34016d){const _0xc7b8db=_0x526707;this[_0xc7b8db(0x182)]={'ja':_0x23513d,'en':_0x37e21e,'zh':_0x2e8aa6,'ko':_0x34fedc,'de':_0xa9753,'ru':_0x34016d},this[_0xc7b8db(0x25f)](_0xc7b8db(0x1b4)),_0x78841d[_0xc7b8db(0x139)](this);}static[_0x526707(0x326)](_0x10ce75){const _0x298165=_0x526707,_0x57e862=JSON[_0x298165(0x2f3)](_0x10ce75);return new _0x24a556(_0x57e862[_0x298165(0x360)],_0x57e862[_0x298165(0x1b4)],_0x57e862['zh_CN'],_0x57e862[_0x298165(0x24a)],_0x57e862[_0x298165(0x1c1)],_0x57e862[_0x298165(0x1a2)]);}[_0x526707(0x2e4)](){const _0x518e41=_0x526707;return this[_0x518e41(0x247)];}[_0x526707(0x29f)](_0x217c84){const _0x5ee938=_0x526707;if(_0x217c84[_0x5ee938(0x30b)](/^ja/))return this[_0x5ee938(0x182)]['ja'];if(_0x217c84['match'](/^en/))return this[_0x5ee938(0x182)]['en'];if(_0x217c84[_0x5ee938(0x30b)](/^de/))return this[_0x5ee938(0x182)]['de'];if(_0x217c84[_0x5ee938(0x30b)](/^zh/))return this[_0x5ee938(0x182)]['zh'];return this[_0x5ee938(0x182)]['en'];}[_0x526707(0x25f)](_0x296e01){const _0x52fff8=_0x526707;this[_0x52fff8(0x247)]=this[_0x52fff8(0x29f)](_0x296e01);}}class _0x4121d2{constructor(){this['_list']=[];}['currentLocal'](){const _0x1521e5=_0x526707;return $dataSystem[_0x1521e5(0x231)];}['add'](_0x2e91b7){this['_list']['push'](_0x2e91b7);}[_0x526707(0x374)](){const _0x3663c3=_0x526707,_0x225321=this[_0x3663c3(0x22c)]();for(const _0x3f43d2 of this[_0x3663c3(0x134)]){_0x3f43d2[_0x3663c3(0x25f)](_0x225321);}}[_0x526707(0x225)](_0x377166){return;}}const _0x78841d=new _0x4121d2();class _0x5746aa{constructor(_0x3f9bd1,_0x18bccd){
                const _0x3cb0d4=_0x526707;this[_0x3cb0d4(0x20f)]=_0x3f9bd1,this[_0x3cb0d4(0x18c)]=_0x18bccd;}[_0x526707(0x2e4)](){const _0x4ecf70=_0x526707;return this[_0x4ecf70(0x18c)][_0x4ecf70(0x2e4)]();}}class _0x406c0a{constructor(_0xc029d6,_0xd25837){const _0x4ecff8=_0x526707;this[_0x4ecff8(0x2f1)]=_0xc029d6;}[_0x526707(0x1e7)](){return 0x140;}}class _0x527e32{constructor(){const _0x33bdd0=_0x526707;this[_0x33bdd0(0x31d)](),this[_0x33bdd0(0x25e)]=![];}[_0x526707(0x13d)](_0x1d5910){const _0x4d1fbe=_0x526707;this[_0x4d1fbe(0x25e)]=_0x1d5910;}['getAutoMode'](){return this['_enabled'];}[_0x526707(0x37b)](){const _0x10ed7a=_0x526707;this['setAutoMode'](!this[_0x10ed7a(0x25e)]);}[_0x526707(0x31d)](){const _0x5a3a79=_0x526707;this[_0x5a3a79(0x300)](null),this[_0x5a3a79(0x174)]();}[_0x526707(0x174)](){const _0x246694=_0x526707;this[_0x246694(0x230)]=0x0;}[_0x526707(0x2da)](){return this['_currentTime'];}[_0x526707(0x260)](){return this['_enabled'];}['updateAutoTime'](_0x576bd1){const _0x1becf8=_0x526707;this['_enabled']&&(this[_0x1becf8(0x230)]+=_0x576bd1);}[_0x526707(0x277)](){this['resetTimer']();}[_0x526707(0x338)](){const _0x4eb1ef=_0x526707;this[_0x4eb1ef(0x32c)]&&this[_0x4eb1ef(0x32c)][_0x4eb1ef(0x274)]()&&(this['_seBuffer'][_0x4eb1ef(0x322)](),this[_0x4eb1ef(0x32c)]=null);}[_0x526707(0x19d)](){const _0x304e19=_0x526707;this[_0x304e19(0x338)](),this['resetTimer']();}[_0x526707(0x368)](){this['_seBuffer']=null;}[_0x526707(0x300)](_0xe5c98){const _0xfd0f1e=_0x526707;this[_0xfd0f1e(0x32c)]=_0xe5c98,_0xe5c98&&_0xe5c98['addStopListener'](this[_0xfd0f1e(0x368)][_0xfd0f1e(0x243)](this));}[_0x526707(0x176)](){const _0x35a5bd=_0x526707;return!this[_0x35a5bd(0x32c)];}['timeRate'](_0x486cda){const _0x1976ab=_0x526707,_0x48b2e6=this[_0x1976ab(0x230)]/_0x486cda;return Math[_0x1976ab(0x393)](0x1,_0x48b2e6);}[_0x526707(0x2b7)](_0x39eeef){const _0x3d404c=_0x526707;if(this[_0x3d404c(0x176)]()){const _0x459011=this[_0x3d404c(0x32e)](_0x39eeef);if(_0x459011>=0x1)return!![];}return![];}}class _0x16fd6e{constructor(_0x24137c,_0x3ccd5a,_0xe54d43){const _0x1d0e24=_0x526707;this[_0x1d0e24(0x245)]=_0x24137c,this[_0x1d0e24(0x342)]=_0x3ccd5a,this['_cancelText']=_0xe54d43;}[_0x526707(0x2b9)](_0x36b5b1){const _0xbbfd60=_0x526707,_0x480ff4=this[_0xbbfd60(0x342)][_0xbbfd60(0x2e4)]();return this[_0xbbfd60(0x245)][_0xbbfd60(0x206)](_0x480ff4,_0x36b5b1);}[_0x526707(0x2ee)](){const _0x1f4787=_0x526707;return this[_0x1f4787(0x2bc)][_0x1f4787(0x2e4)]();}}class _0x1219a3{constructor(_0x97148d,_0x42fd61,_0x580d6d,_0x1c492f,_0x2d1ab8,_0x2f2734,_0x50e554){const _0x5f472b=_0x526707;this['_itemstyle']=_0x97148d,this[_0x5f472b(0x23e)]=_0x42fd61||null,this[_0x5f472b(0x164)]=_0x1c492f||null,this['_frameColor']=_0x2d1ab8||null,this[_0x5f472b(0x214)]=_0x580d6d,this['_machinakaRect']=_0x2f2734,this[_0x5f472b(0x15f)]=_0x50e554;}static[_0x526707(0x326)](_0x2c5ddb,_0x1ac3ce){const _0x2446ae=_0x526707,_0x24e432=JSON[_0x2446ae(0x2f3)](_0x2c5ddb),_0x2fe6b9=_0x24e432[_0x2446ae(0x19a)],_0x8a570c=_0x24e432[_0x2446ae(0x36d)],_0x377751=_0x24e432['background'],_0x3060e1=Number(_0x24e432[_0x2446ae(0x2f4)]),_0x120b09=_0x24e432[_0x2446ae(0x1ea)]?_0x3c99d0(_0x24e432[_0x2446ae(0x165)][_0x2446ae(0x1ea)]):null,_0xb693af=_0x24e432[_0x2446ae(0x162)]?_0x3c99d0(_0x24e432[_0x2446ae(0x162)]):null,_0x6325b0=_0x24e432[_0x2446ae(0x14c)]||null,_0x56e3f6=Number(_0x24e432[_0x2446ae(0x323)]||0x2),_0x4d7ded={'voiceIcon':_0x3060e1,'numFaceLines':0x4,'lineSpacing':_0x56e3f6,'speakerNameFormat':_0x8a570c};return new _0x1219a3(_0x4d7ded,_0x2fe6b9,_0xb693af,_0x377751,_0x6325b0,_0x120b09,_0x1ac3ce['choice']);}[_0x526707(0x244)](){const _0x5e2aef=_0x526707;return this[_0x5e2aef(0x349)][_0x5e2aef(0x244)];}[_0x526707(0x316)](){return this['_itemstyle'];}[_0x526707(0x285)](){const _0x405c5c=_0x526707;if(this['_windowRect'])return this[_0x405c5c(0x214)]['clone']();return null;}[_0x526707(0x18a)](){const _0x39e187=_0x526707;if(this[_0x39e187(0x164)])return ImageManager[_0x39e187(0x1e4)](this['_background']);return null;}[_0x526707(0x2f7)](){const _0x4b2779=_0x526707;if(this[_0x4b2779(0x23e)])return ImageManager[_0x4b2779(0x1e4)](this[_0x4b2779(0x23e)]);return null;}[_0x526707(0x389)](){return 0x8;}['speakerNameFormat'](){const _0x1a5b17=_0x526707;return this[_0x1a5b17(0x349)][_0x1a5b17(0x387)];}[_0x526707(0x2b9)](_0x4c92ba){const _0x42792d=_0x526707;return this[_0x42792d(0x15f)]['createChoiceItemText'](_0x4c92ba);}[_0x526707(0x2ee)](){const _0x202d5c=_0x526707,_0x2ff435=this[_0x202d5c(0x15f)][_0x202d5c(0x2ee)]();return this[_0x202d5c(0x2b9)](_0x2ff435);}['itemFrameThickness'](){return 0x4;}[_0x526707(0x2b5)](){const _0x36ce7a=_0x526707;return this[_0x36ce7a(0x1b6)];}}class _0x1763a3{constructor(_0x334813,_0x7a3e54){const _0x268678=_0x526707;this[_0x268678(0x281)]=_0x334813,this[_0x268678(0x197)]=_0x7a3e54;}[_0x526707(0x15a)](){const _0x264ee6=_0x526707;for(const _0x468cc1 of[this[_0x264ee6(0x281)],this[_0x264ee6(0x197)]]){$gameSwitches[_0x264ee6(0x195)](_0x468cc1,!![]);}}[_0x526707(0x213)](){const _0x250213=_0x526707;return this[_0x250213(0x311)](this[_0x250213(0x197)]);}[_0x526707(0x2b8)](){const _0x1eb5e4=_0x526707;return this['readSwitch'](this[_0x1eb5e4(0x281)]);}[_0x526707(0x311)](_0x13c7e6){if(_0x13c7e6<=0x0)return!![];return $gameSwitches['value'](_0x13c7e6);}}class _0x57e033{constructor(_0x46d870,_0x4c19ab){const _0x33171e=_0x526707;this[_0x33171e(0x1d1)]=_0x46d870,this[_0x33171e(0x1b5)]=_0x4c19ab;}['initSwitch'](){const _0x2ac11b=_0x526707;$gameSwitches[_0x2ac11b(0x195)](this[_0x2ac11b(0x1d1)],this[_0x2ac11b(0x1b5)]);}[_0x526707(0x215)](){const _0x276bc2=_0x526707;if(this[_0x276bc2(0x1d1)]>0x0)return $gameSwitches[_0x276bc2(0x170)](this[_0x276bc2(0x1d1)]);return this[_0x276bc2(0x1b5)];}}class _0x2cf71e{constructor(_0x1c5f6b,_0x3e9338,_0x3dfca1,_0x5f57d5,_0x1d09e0,_0x538f59,_0x4a9a64,_0x24bb25){const _0xb2be4f=_0x526707;this[_0xb2be4f(0x261)]=_0x5f57d5,this[_0xb2be4f(0x1eb)]=_0x1c5f6b,this[_0xb2be4f(0x320)]=_0x1d09e0,this[_0xb2be4f(0x1df)]=_0x3e9338,this[_0xb2be4f(0x317)]=_0x3dfca1,this[_0xb2be4f(0x1ae)]=_0x538f59,this[_0xb2be4f(0x306)]=_0x4a9a64,this[_0xb2be4f(0x14d)]=_0x24bb25;}[_0x526707(0x15a)](){const _0x4b586e=_0x526707;this['_logSwitch'][_0x4b586e(0x15a)](),this[_0x4b586e(0x14d)][_0x4b586e(0x2dd)]();}['logStyle'](){const _0x5b48c1=_0x526707;return this[_0x5b48c1(0x1df)];}[_0x526707(0x2b9)](_0x2fea75){const _0x2d00c7=_0x526707;return this[_0x2d00c7(0x1df)][_0x2d00c7(0x2b9)](_0x2fea75);}['autoTime'](){const _0x108064=_0x526707;return this[_0x108064(0x317)][_0x108064(0x1e7)]();}[_0x526707(0x2b8)](){const _0x355dd2=_0x526707;if(!this[_0x355dd2(0x320)]){if($gameParty[_0x355dd2(0x1e6)]())return![];}return this[_0x355dd2(0x261)][_0x355dd2(0x2b8)]();}[_0x526707(0x290)](){return this['_machinakaMode']['isEnabled']();}['canSave'](){return!![];}['isVoiceFile'](_0xdffa8e){const _0x226af0=_0x526707;if(_0xdffa8e)return this['_voice']['isVoiceFile'](_0xdffa8e[_0x226af0(0x34c)]);return![];}[_0x526707(0x369)](_0x41d44f){const _0x26afda=_0x526707,_0x5abadc={'keepingAutoMode':!!_0x41d44f[_0x26afda(0x31c)],'autoWaitTime':_0x25a2ac(_0x41d44f[_0x26afda(0x212)],this[_0x26afda(0x1ae)][_0x26afda(0x212)]),'logLimitBasic':_0x25a2ac(_0x41d44f[_0x26afda(0x187)],this[_0x26afda(0x1ae)]['logLimitBasic']),'logLimitExtends':_0x25a2ac(_0x41d44f[_0x26afda(0x2cf)],this[_0x26afda(0x1ae)][_0x26afda(0x2cf)]),'gaugeColor':_0x25a2ac(_0x41d44f['gaugeColor'],this[_0x26afda(0x1ae)][_0x26afda(0x2c3)]),'machinakaLines':_0x25a2ac(_0x41d44f[_0x26afda(0x25a)],this[_0x26afda(0x1ae)][_0x26afda(0x25a)])};return _0x5abadc;}[_0x526707(0x232)](){const _0x532fc0=_0x526707;return this[_0x532fc0(0x369)](this[_0x532fc0(0x1ae)]);}['menuCommand'](){const _0x3eee07=_0x526707;return this[_0x3eee07(0x306)];}}function _0x25a2ac(_0x4c72c0,_0x5d00bb){return isNaN(_0x4c72c0)?_0x5d00bb:Number(_0x4c72c0);}class _0x291a80{constructor(){const _0x33ba15=_0x526707;this[_0x33ba15(0x31d)]();}[_0x526707(0x31d)](){const _0x4c6177=_0x526707;this['_textState']=null,this[_0x4c6177(0x355)]=null,this[_0x4c6177(0x394)]=null;}[_0x526707(0x33d)](_0xcef645){const _0x25e73=_0x526707;this[_0x25e73(0x355)]&&this[_0x25e73(0x355)][_0x25e73(0x33d)](_0xcef645);}['startMessage'](_0x4337e2,_0x3109f5,_0x4295ac){const _0x43a1d7=_0x526707;this[_0x43a1d7(0x355)]&&this[_0x43a1d7(0x355)][_0x43a1d7(0x20e)](_0x4337e2,_0x3109f5,_0x4295ac);}[_0x526707(0x21a)](_0x53362b,_0x43704a,_0x47af2e,_0x5310a8){const _0x515e37=_0x526707;this['_logItem']&&this['_logItem'][_0x515e37(0x24b)](_0x53362b,_0x43704a,_0x47af2e,_0x5310a8,this[_0x515e37(0x394)]);}[_0x526707(0x373)](){const _0x4e4d5f=_0x526707;return this[_0x4e4d5f(0x355)];}['setLastVoice'](_0x7d66d3){const _0x8c2192=_0x526707;if(!_0x7d66d3){this[_0x8c2192(0x394)]=null;return;}const _0x359b99={'name':_0x7d66d3[_0x8c2192(0x34c)],'pan':_0x7d66d3[_0x8c2192(0x37e)],'pitch':_0x7d66d3['pitch'],'pos':_0x7d66d3[_0x8c2192(0x144)]||0x0,'volume':_0x7d66d3[_0x8c2192(0x1fe)]};this[_0x8c2192(0x394)]=_0x359b99;}['hasVoice'](){return!!this['_se'];}[_0x526707(0x16c)](){}[_0x526707(0x268)](){const _0x287632=_0x526707;return!!this[_0x287632(0x355)];}['close'](){const _0x1578f1=_0x526707;this[_0x1578f1(0x31d)]();}[_0x526707(0x2d7)](){const _0x42e567=_0x526707;this[_0x42e567(0x355)]=new _0x1b41ac();}}class _0x47f5c3{constructor(){const _0x5809f3=_0x526707;this[_0x5809f3(0x2eb)]=new _0x291a80();}}class _0x322ae5{constructor(){const _0x39282b=_0x526707;this[_0x39282b(0x27a)](![]),this[_0x39282b(0x250)](![]),this['setParallelMode'](![]),this['setTextTerminate'](![]),this[_0x39282b(0x188)](NaN);}[_0x526707(0x188)](_0x3123c8){const _0xf5fade=_0x526707;this[_0xf5fade(0x242)]=_0x3123c8;}[_0x526707(0x246)](_0x267add){this['_textTerminate']=!!_0x267add;}['setParallelMode'](_0x14af9f){const _0x4b9aba=_0x526707;this[_0x4b9aba(0x131)]=_0x14af9f,this[_0x4b9aba(0x2bb)]=!![];}[_0x526707(0x21e)](){const _0x2023f6=_0x526707;return!this[_0x2023f6(0x131)];}[_0x526707(0x250)](_0x4cf692){this['_needsShowFast']=!!_0x4cf692;}['needsShowFast'](){
                    const _0x2eddbb=_0x526707;return this[_0x2eddbb(0x379)];}['setBattleMode'](_0x3f5916){this['_battleMode']=_0x3f5916;}[_0x526707(0x2a9)](){const _0x4d3bcb=_0x526707;return this[_0x4d3bcb(0x1fd)];}}class _0x1e9f4e{constructor(_0x386d14){const _0x429f8=_0x526707;this[_0x429f8(0x2c0)](_0x386d14);}[_0x526707(0x265)](){const _0x2dbf6f=_0x526707;return this[_0x2dbf6f(0x364)][_0x2dbf6f(0x2cf)];}[_0x526707(0x23f)](){const _0x4ac7f8=_0x526707;return this[_0x4ac7f8(0x364)][_0x4ac7f8(0x187)];}['quickSaveFileName'](){const _0x2d6178=_0x526707;return this[_0x2d6178(0x163)]();}[_0x526707(0x163)](){const _0x4b4f7d=_0x526707;return _0x4b4f7d(0x1b0);}['setOptionValue'](_0x52ff48){const _0x82f7e9=_0x526707;this[_0x82f7e9(0x364)]=_0x52ff48;}[_0x526707(0x2cd)](_0x57688b){const _0x2a62d5=_0x526707;!isNaN(_0x57688b)&&(this[_0x2a62d5(0x364)]['logLimitExtends']=Math[_0x2a62d5(0x358)](0xa,_0x57688b));}['getLogLimitSizeBasic'](){return this['_value']['logLimitBasic'];}[_0x526707(0x1c2)](_0x3aaaf5){const _0x177dff=_0x526707;!isNaN(_0x3aaaf5)&&(this[_0x177dff(0x364)][_0x177dff(0x2cf)]=Math[_0x177dff(0x358)](0x4,_0x3aaaf5));}[_0x526707(0x1d5)](){const _0x2d7f43=_0x526707;return this['_value'][_0x2d7f43(0x2cf)];}['getAutoWaitTime'](){const _0x31206b=_0x526707;return this[_0x31206b(0x364)][_0x31206b(0x212)];}[_0x526707(0x1f5)](_0x2d54f8){const _0x38b33b=_0x526707;!Number['isNaN'](_0x2d54f8)&&(this[_0x38b33b(0x364)][_0x38b33b(0x212)]=Math[_0x38b33b(0x358)](0xa,_0x2d54f8));}[_0x526707(0x1a0)](){const _0x21cefb=_0x526707;return!!this[_0x21cefb(0x364)][_0x21cefb(0x31c)];}[_0x526707(0x284)](){const _0x53ecfb=_0x526707;return this[_0x53ecfb(0x364)][_0x53ecfb(0x2c3)];}[_0x526707(0x25a)](){const _0x4babdd=_0x526707;return this[_0x4babdd(0x364)]['machinakaLines'];}[_0x526707(0x2af)](){const _0x34a74e=_0x526707;return{'keepingAutoMode':this[_0x34a74e(0x364)][_0x34a74e(0x31c)],'logLimitBasic':this['_value']['logLimitBasic'],'logLimitExtends':this[_0x34a74e(0x364)][_0x34a74e(0x2cf)],'autoWaitTime':this[_0x34a74e(0x364)][_0x34a74e(0x212)],'gaugeColor':this[_0x34a74e(0x364)]['gaugeColor'],'machinakaLines':this[_0x34a74e(0x364)][_0x34a74e(0x25a)]};}}class _0x379330{constructor(){const _0x256016=_0x526707;this[_0x256016(0x318)]=new Set();}[_0x526707(0x1d7)](_0x3403d8){}}class _0x59c154{constructor(){this['setGaugeFunction'](_0x42e5f9=>{const _0x45a55f=_0x563b,_0x2a0364=new _0x16fd27(_0x42e5f9[_0x45a55f(0x2e9)]),_0x2d5d05=ImageManager['loadSystem'](_0x42e5f9[_0x45a55f(0x2c5)]);return _0x2a0364[_0x45a55f(0x2fe)](_0x2d5d05,_0x42e5f9[_0x45a55f(0x2dc)],_0x42e5f9[_0x45a55f(0x30c)]),_0x2a0364;});}['setGaugeFunction'](_0x5cb28a){this['_autoGaugeFunc']=_0x5cb28a;}[_0x526707(0x1c7)](_0x14f582){const _0x1147c3=_0x526707;if(this[_0x1147c3(0x1e2)]){const _0x30901a=this[_0x1147c3(0x1e2)](_0x14f582);return _0x30901a['setValue'](0x0),_0x30901a;}return null;}}function _0x1710b6(_0x3e3bf3){const _0x4ac864=_0x526707;let _0x36f809=_0x3e3bf3;for(let _0x4651ee=0x0;_0x4651ee<0x64;++_0x4651ee){const _0x4eba4b=$dataMapInfos[_0x36f809];if(!_0x4eba4b)return _0x36f809;_0x36f809=_0x4eba4b[_0x4ac864(0x336)];}return 0x0;}class _0x543356{constructor(){const _0x1fd80f=_0x526707;this[_0x1fd80f(0x28e)](0x0);}[_0x526707(0x28e)](_0x139dc4){const _0x2afe4e=_0x526707;this[_0x2afe4e(0x27c)]=_0x139dc4;}[_0x526707(0x1f3)](){}}function _0x4e9942(){const _0x330025=_0x526707;let _0x261b5e=$gameMap[_0x330025(0x1ab)];for(let _0x3f7d15=0x0;_0x3f7d15<0x3f2;++_0x3f7d15){if(!_0x261b5e[_0x330025(0x1af)])return _0x261b5e;_0x261b5e=_0x261b5e['_childInterpreter'];}return null;}class _0x47c130{[_0x526707(0x375)](){return _0x53d28a;}constructor(_0x21167e,_0x5482ad,_0x46527e){const _0x271eb0=_0x526707;this['setWorkaround'](_0x21167e),this[_0x271eb0(0x169)]=null,this[_0x271eb0(0x377)]=new _0x527e32(),this[_0x271eb0(0x356)](),this[_0x271eb0(0x23b)]=_0x5482ad,this[_0x271eb0(0x25d)]=new _0x1e9f4e(_0x5482ad['cloneDefaultOption']()),this[_0x271eb0(0x130)]=_0x46527e;}[_0x526707(0x26b)](_0x33151c){}[_0x526707(0x2c0)](_0x598081){const _0x50f5f1=_0x526707;if(_0x598081){const _0xee16a1=this[_0x50f5f1(0x23b)][_0x50f5f1(0x369)](_0x598081);this[_0x50f5f1(0x25d)]['setOptionValue'](_0xee16a1);}else this[_0x50f5f1(0x25d)][_0x50f5f1(0x2c0)](this[_0x50f5f1(0x23b)][_0x50f5f1(0x232)]());}[_0x526707(0x2a6)](){const _0x540eb5=_0x526707,_0x36c232=this[_0x540eb5(0x25d)][_0x540eb5(0x2af)]();return this[_0x540eb5(0x23b)][_0x540eb5(0x369)](_0x36c232);}[_0x526707(0x239)](){return this['_option'];}['openOptionScene'](){}['getLogItemStyle'](){const _0x20746f=_0x526707;return this[_0x20746f(0x25c)]()['logStyle']()[_0x20746f(0x316)]();}[_0x526707(0x2cc)](_0xc26378){this['_workaround']=_0xc26378;}[_0x526707(0x30f)](){const _0x32301e=_0x526707;return this[_0x32301e(0x2ed)];}[_0x526707(0x12e)](_0x5b79b8,_0x3cb8f1){const _0x4bb699=_0x526707;this[_0x4bb699(0x169)]&&this['_contents'][_0x4bb699(0x20c)](_0x3cb8f1,_0x5b79b8[_0x4bb699(0x312)]());}[_0x526707(0x190)](){const _0x6146c6=_0x526707;return this['getContents']()[_0x6146c6(0x190)]();}[_0x526707(0x2a8)](_0x28d00b){const _0x40dad0=_0x526707,_0x2b2ee6=this[_0x40dad0(0x36f)]();}[_0x526707(0x29e)](_0x1f47f7){const _0x528497=_0x526707,_0x257f4b=_0x1f47f7[_0x528497(0x1dc)]()['name'];if(!_0x257f4b)return![];if(_0x257f4b[_0x528497(0x30b)](/^EV\d{1,3}/))return![];return!![];}[_0x526707(0x2ec)](){return new _0x470fe1(this['pluginVersion']());}[_0x526707(0x270)](){const _0x310248=_0x526707;this[_0x310248(0x2d1)](this['createEmptySaveContents']());}['clearOldData'](){const _0x1fc703=_0x526707;if(this[_0x1fc703(0x169)]){const _0x12ae22=this[_0x1fc703(0x239)]();this[_0x1fc703(0x169)]['checkLogSize'](_0x12ae22['logSizeYellow'](),_0x12ae22['logSizeRed']());}}[_0x526707(0x2d1)](_0x5f035f){const _0x10277b=_0x526707;this[_0x10277b(0x169)]=_0x5f035f,this[_0x10277b(0x2bd)]();}[_0x526707(0x1fa)](){const _0x57f12d=_0x526707;return this[_0x57f12d(0x169)]['logSize']();}['getContents'](){const _0x2cb9d1=_0x526707;return this[_0x2cb9d1(0x169)];}[_0x526707(0x2bd)](){const _0x5d546f=_0x526707;!this[_0x5d546f(0x169)]&&(this[_0x5d546f(0x169)]=this[_0x5d546f(0x2ec)]());}[_0x526707(0x2a4)](_0x2e1b12){const _0x57258f=_0x526707;if(!_0x2e1b12)return!![];try{const _0x38085d=_0x2e1b12[_0x57258f(0x193)]();if(_0x38085d!==this[_0x57258f(0x375)]())return![];this['setContents'](_0x2e1b12);}catch(_0x1c9323){return console[_0x57258f(0x253)](_0x1c9323),console[_0x57258f(0x253)](_0x2e1b12),![];}const _0x584d5c=_0x2e1b12[_0x57258f(0x334)](),_0x183b62=_0x4e9942();return!isNaN(_0x584d5c)&&_0x183b62&&_0x183b62[_0x57258f(0x1e8)]()&&_0x183b62[_0x57258f(0x2cb)](_0x584d5c),!![];}[_0x526707(0x1e9)](_0x293f8a){const _0xa31913=_0x526707;this[_0xa31913(0x356)](),this['_contents']=null;const _0x121ac6=_0x293f8a[_0xa31913(0x26d)],_0x59f86a=this[_0xa31913(0x2a4)](_0x121ac6);this[_0xa31913(0x2bd)]();if(!_0x59f86a){}}['resetTemporaly'](){const _0x223963=_0x526707;this['_autoTemporary']['setLastVoiceBuffer'](null),this['_temporaly']=new _0x322ae5(),this[_0x223963(0x359)]=new _0x291a80();}[_0x526707(0x291)](){const _0x18b872=_0x526707;this[_0x18b872(0x130)][_0x18b872(0x15a)](),this['_readOnlyData'][_0x18b872(0x15a)](),this[_0x18b872(0x356)](),this[_0x18b872(0x270)]();}['onBoot'](){}['setJumpTarget'](_0x3d0bcc,_0x45f99d){}[_0x526707(0x1f7)](_0x46c3d6,_0x16a1e2){}['readOnryData'](){const _0x33409b=_0x526707;return this[_0x33409b(0x23b)];}['machinakaLines'](){const _0xd441d1=_0x526707;return this['_option'][_0xd441d1(0x25a)]();}[_0x526707(0x219)](){const _0x467d6b=_0x526707,_0x598d89=this[_0x467d6b(0x130)];if(_0x598d89[_0x467d6b(0x249)]())return new _0x3cb633(_0x598d89);if(_0x598d89['isAbsolute']())return new _0x4b048a(_0x598d89);return new _0x1a5366(_0x598d89);}[_0x526707(0x387)](){const _0x152b0a=_0x526707;return this[_0x152b0a(0x23b)][_0x152b0a(0x14b)]()[_0x152b0a(0x387)]();}['createChoiceItemText'](_0x4c605d){const _0x4ab53e=_0x526707;return this[_0x4ab53e(0x23b)][_0x4ab53e(0x2b9)](_0x4c605d);}[_0x526707(0x330)](_0xf051d0){const _0xb9ef32=_0x526707;this[_0xb9ef32(0x2f6)][_0xb9ef32(0x330)](_0xf051d0);}['canSave'](){const _0xdfb6e2=_0x526707;return $gameSystem['isSaveEnabled']()&&this[_0xdfb6e2(0x2f6)][_0xdfb6e2(0x21e)]()&&this[_0xdfb6e2(0x23b)][_0xdfb6e2(0x21e)]();}['writeSaveContents'](_0x1ff2d6){const _0x4f6c22=_0x526707;_0x1ff2d6[_0x4f6c22(0x26d)]=this[_0x4f6c22(0x385)]();}[_0x526707(0x1d6)](_0x585bf7){const _0x57314c=_0x526707;SceneManager[_0x57314c(0x1f2)](_0x585bf7),this['_temporaly'][_0x57314c(0x250)](!![]);}[_0x526707(0x2d8)](){const _0x4d6412=_0x526707;return this[_0x4d6412(0x2f6)][_0x4d6412(0x2d8)]();}['isInputEnabled'](){const _0x53b102=_0x526707;if($gameMessage[_0x53b102(0x279)]()||$gameMessage[_0x53b102(0x23d)]())return![];return!![];}[_0x526707(0x17e)](){const _0x511fb9=_0x526707;this[_0x511fb9(0x2bf)]()&&this[_0x511fb9(0x130)][_0x511fb9(0x17e)]();}[_0x526707(0x143)](){return 0x1;}['startAutoTimer'](){}[_0x526707(0x1ed)](){const _0x5ec1ea=_0x526707;this[_0x5ec1ea(0x377)][_0x5ec1ea(0x31d)]();}[_0x526707(0x34f)](){const _0x3eb494=_0x526707;return this[_0x3eb494(0x377)][_0x3eb494(0x32e)](this[_0x3eb494(0x25d)][_0x3eb494(0x152)]());}[_0x526707(0x210)](){const _0x29c4f4=_0x526707;this[_0x29c4f4(0x377)][_0x29c4f4(0x1a5)](0x1);}[_0x526707(0x176)](){const _0x503c2d=_0x526707;return this[_0x503c2d(0x377)][_0x503c2d(0x176)]();}['needsTextTerminate'](){const _0x12106a=_0x526707,_0x5721b6=this[_0x12106a(0x25d)][_0x12106a(0x152)]();return this['_autoTemporary']['needsNextMessage'](_0x5721b6+0x14);}[_0x526707(0x33d)](_0x23db73){const _0x7b6f1c=_0x526707;this[_0x7b6f1c(0x359)][_0x7b6f1c(0x33d)](_0x23db73);}['onEnedOfText'](){const _0x269598=_0x526707,_0x46e85e=this[_0x269598(0x359)][_0x269598(0x373)]();_0x46e85e&&this[_0x269598(0x345)](_0x46e85e),this[_0x269598(0x359)]['close']();}[_0x526707(0x20e)](_0xf8c322,_0x321a29){const _0x5c02a7=_0x526707,_0x363821=$gameMessage['faceName'](),_0x5cfd10=$gameMessage['faceIndex']();
                    this[_0x5c02a7(0x359)][_0x5c02a7(0x21a)](_0xf8c322,_0x321a29,_0x363821,_0x5cfd10),this[_0x5c02a7(0x377)][_0x5c02a7(0x277)](),this[_0x5c02a7(0x2f6)][_0x5c02a7(0x250)](![]);}[_0x526707(0x19d)](){const _0x1cb88b=_0x526707;this[_0x1cb88b(0x377)][_0x1cb88b(0x19d)]();}[_0x526707(0x1b9)](_0x371248){const _0x33604f=_0x526707,_0x11bc4c=this[_0x33604f(0x36f)]();_0x11bc4c[_0x33604f(0x334)]()===_0x371248?(this[_0x33604f(0x183)](),this[_0x33604f(0x359)][_0x33604f(0x327)]()):(_0x11bc4c[_0x33604f(0x1b9)](_0x371248),this[_0x33604f(0x2b8)]()&&this[_0x33604f(0x359)][_0x33604f(0x2d7)]());}[_0x526707(0x365)](){const _0xb910cc=_0x526707;return this[_0xb910cc(0x36f)]()[_0xb910cc(0x365)]();}['setBattleMode'](_0x562f78){const _0xd0692b=_0x526707;this['_temporaly'][_0xd0692b(0x27a)](_0x562f78);}['isLogButtonEnabled'](){const _0x352ee0=_0x526707;return!this[_0x352ee0(0x2f6)]['isBattleMode']();}['isLogWriteEnabled'](){const _0x18884f=_0x526707;return this[_0x18884f(0x23b)][_0x18884f(0x2b8)]();}[_0x526707(0x180)](){const _0xeb028c=_0x526707;if(Utils[_0xeb028c(0x1db)]())return!![];if(Utils['isLocal']())return!![];return![];}['getSaveContents'](){const _0x499a5c=_0x526707;if(!this[_0x499a5c(0x169)])return null;if(this[_0x499a5c(0x180)]())return this[_0x499a5c(0x169)];return this[_0x499a5c(0x169)][_0x499a5c(0x32b)]();}[_0x526707(0x183)](){const _0x9ca5c0=_0x526707;if(this[_0x9ca5c0(0x176)]()){const _0x3c07a2=this[_0x9ca5c0(0x36f)]()[_0x9ca5c0(0x204)]();_0x3c07a2&&ManoUZ_MessageLog[_0x9ca5c0(0x26e)](_0x3c07a2,{});}}[_0x526707(0x35b)](){const _0x2e86e8=_0x526707;if(this['_messageStream'][_0x2e86e8(0x2f5)]())return!![];const _0x276cd2=this['getContents'](),_0x3bea04=_0x276cd2[_0x2e86e8(0x204)]();return!!_0x3bea04;}[_0x526707(0x1de)](_0xe44afc,_0xbe9ebc){const _0x8746f6=_0x526707;if(_0xe44afc===-0x2){const _0x5746fe=this[_0x8746f6(0x25c)]()['logStyle']()['cancelText'](),_0xbc086a=new _0x28ba4a(_0x5746fe,_0xe44afc);this[_0x8746f6(0x345)](_0xbc086a);return;}if(0x0<=_0xe44afc&&_0xe44afc<_0xbe9ebc['maxItems']()){const _0x25db44=_0xbe9ebc[_0x8746f6(0x1d3)](_0xe44afc),_0x3745af=_0xbe9ebc[_0x8746f6(0x2ca)](_0x25db44),_0x492f95=this[_0x8746f6(0x25c)]()[_0x8746f6(0x14b)]()[_0x8746f6(0x2b9)](_0x3745af),_0x348056=new _0x28ba4a(_0x492f95,_0xe44afc);this[_0x8746f6(0x345)](_0x348056);}}[_0x526707(0x345)](_0x198dfa){const _0x2417e4=_0x526707;if(!this[_0x2417e4(0x2b8)]())return;const _0x3956f3=this['getContents']();_0x3956f3['addItem'](_0x198dfa);}[_0x526707(0x203)](){const _0x5b8727=_0x526707;return!isNaN(this[_0x5b8727(0x169)][_0x5b8727(0x334)]());}['onEndEvent'](){const _0x582bfe=_0x526707;this[_0x582bfe(0x169)][_0x582bfe(0x173)](),this['_contents']['saveCurrentLog'](),this[_0x582bfe(0x211)](),this['_messageStream'][_0x582bfe(0x31d)](),this[_0x582bfe(0x142)]();}[_0x526707(0x252)](_0x450aaa,_0x4a9d44){const _0x802862=_0x526707,_0x39091a=this['_readOnlyData'][_0x802862(0x1d7)](_0x450aaa);return _0x39091a&&this[_0x802862(0x359)][_0x802862(0x1bc)](_0x450aaa),_0x39091a;}['setLastVoiceBuffer'](_0x55f538){const _0x3c045f=_0x526707;this[_0x3c045f(0x377)][_0x3c045f(0x300)](_0x55f538);}[_0x526707(0x13d)](_0x35e89e){const _0x3b2cb8=_0x526707;this[_0x3b2cb8(0x377)][_0x3b2cb8(0x13d)](!!_0x35e89e);}[_0x526707(0x38f)](){const _0x3f2eb8=_0x526707;return this[_0x3f2eb8(0x377)][_0x3f2eb8(0x38f)]();}['changeAutoMode'](){const _0x495fee=_0x526707;this[_0x495fee(0x377)]['flipAutoMode']();}[_0x526707(0x17d)](){const _0x34f09d=_0x526707;if(this['_option'][_0x34f09d(0x1a0)]())return![];if($gameMessage[_0x34f09d(0x191)]())return![];return!$gameMap['isEventRunning']();}[_0x526707(0x142)](){const _0x2901b6=_0x526707;this[_0x2901b6(0x17d)]()&&this[_0x2901b6(0x377)]['setAutoMode'](![]);}[_0x526707(0x321)](){const _0x464969=_0x526707;return this[_0x464969(0x377)]['isAutoMode']();}}function _0x178b6d(){return PluginManager['parameters'](_0x3b171d);}function _0x396254(_0x3ff6c0){const _0x42c09f=_0x526707,_0x4253ae=Number(_0x3ff6c0[_0x42c09f(0x280)]||0x0),_0x4194a7=_0x32bcf8[_0x42c09f(0x326)](_0x3ff6c0[_0x42c09f(0x33f)]),_0x205e84=new _0x1df67e(_0x4194a7,_0x49a9f6['create'](_0x3ff6c0[_0x42c09f(0x314)]),_0x42c09f(0x18d)),_0xc3e135=new _0x38e254(_0x49a9f6[_0x42c09f(0x326)](_0x3ff6c0[_0x42c09f(0x1c3)]),_0x42c09f(0x2ce)),_0x1cb9a7=new _0x4c7a58(_0x49a9f6[_0x42c09f(0x326)](_0x3ff6c0[_0x42c09f(0x251)]),_0x42c09f(0x237)),_0x5a3daf=new _0x75685d(_0x49a9f6[_0x42c09f(0x326)](_0x3ff6c0[_0x42c09f(0x361)]),_0x42c09f(0x1c0)),_0x5b0994=new _0x10ad5f(_0x49a9f6[_0x42c09f(0x326)](_0x3ff6c0[_0x42c09f(0x235)]),null),_0x380336=new _0x5bfc81(_0x4253ae,_0x49a9f6[_0x42c09f(0x326)](_0x3ff6c0[_0x42c09f(0x216)]),'skip'),_0x118e25=[_0xc3e135,_0x1cb9a7,_0x5a3daf,_0x5b0994,_0x380336,_0x205e84][_0x42c09f(0x228)](_0x51165e=>{const _0x5af922=_0x42c09f;return _0x51165e[_0x5af922(0x2c9)]();}),_0x2a6352=_0x2377f2['create'](_0x3ff6c0[_0x42c09f(0x391)],_0x118e25);return _0x2a6352;}const _0x3455ea=(function(){const _0x40f91e=_0x526707,_0x5a8c18=_0x178b6d(),_0x2746a9=Number(_0x5a8c18[_0x40f91e(0x2de)]||0x3),_0x8af271=Number(_0x5a8c18[_0x40f91e(0x2c7)]||0x0),_0x1bba56=_0x40f91e(0x15d)===_0x5a8c18[_0x40f91e(0x1ff)],_0x1a3ef3=new _0x57e033(_0x8af271,_0x1bba56),_0x45b691={'autoWaitTime':Number(_0x5a8c18[_0x40f91e(0x212)]||0x168),'logLimitBasic':Number(_0x5a8c18['logLimitBasic']||0x28),'logLimitExtends':Number(_0x5a8c18[_0x40f91e(0x2cf)]||0x14),'keepingAutoMode':![],'gaugeColor':0xff0000,'machinakaLines':_0x2746a9},_0x12f3e0=_0x24a556[_0x40f91e(0x326)](_0x5a8c18[_0x40f91e(0x1e5)]),_0x16716f=String(_0x5a8c18[_0x40f91e(0x263)]),_0x43bcdd=_0x24a556[_0x40f91e(0x326)](_0x5a8c18[_0x40f91e(0x2d9)]),_0x23c753=_0x1219a3['create'](_0x5a8c18[_0x40f91e(0x14b)],{'choice':new _0x16fd6e(_0x16716f,_0x12f3e0,_0x43bcdd)}),_0x384cb7=_0x396254(_0x5a8c18),_0x2e702b=new _0x406c0a([],null),_0x2baabd=_0x4c5490['create'](_0x5a8c18[_0x40f91e(0x132)]),_0x43a0f4=Number(_0x5a8c18[_0x40f91e(0x1ce)]),_0x4f57b3=_0x5a8c18[_0x40f91e(0x1a3)]===_0x40f91e(0x15d),_0x53d86a={'commandName':_0x24a556[_0x40f91e(0x326)](_0x5a8c18[_0x40f91e(0x155)]||'{}'),'symbol':'UZMSGLOG'},_0x398a74=new _0x1763a3(_0x43a0f4,0x0),_0x364afb=new _0x2cf71e(_0x2baabd,_0x23c753,_0x2e702b,_0x398a74,_0x4f57b3,_0x45b691,_0x53d86a,_0x1a3ef3),_0x208232=Utils[_0x40f91e(0x1a4)]==='MZ'?new _0x428bdc():null,_0x3cccc0=new _0x47c130(_0x208232,_0x364afb,_0x384cb7);return _0x3cccc0;}()),_0x2790a7=Game_Interpreter[_0x526707(0x37c)][_0x526707(0x310)];Game_Interpreter[_0x526707(0x37c)][_0x526707(0x310)]=function(_0x2e2610){const _0x4c523b=_0x526707,_0x2ab89a=this['_index'],_0x56b18f=_0x2790a7[_0x4c523b(0x17b)](this,_0x2e2610);return _0x56b18f&&_0x3455ea[_0x4c523b(0x1b9)](_0x2ab89a),_0x56b18f;};const _0x4c115=Game_Interpreter[_0x526707(0x37c)]['command250'];Game_Interpreter[_0x526707(0x37c)][_0x526707(0x30e)]=function(_0x4016f5){const _0x6e0a45=_0x526707,_0x339e17=_0x4c115['call'](this,_0x4016f5);if(!_0x3455ea[_0x6e0a45(0x2b8)]())return _0x339e17;const _0x554983=_0x3455ea[_0x6e0a45(0x252)](_0x4016f5[0x0],null);if(_0x554983){const _0x4fd6a9=_0x1abefe();_0x3455ea['setLastVoiceBuffer'](_0x4fd6a9);}return _0x339e17;};function _0x1abefe(){const _0x143969=_0x526707,_0x2385fd=AudioManager['_seBuffers'][_0x143969(0x17f)],_0x201ca3=AudioManager['_seBuffers'][_0x2385fd-0x1];if(_0x201ca3)return _0x201ca3;return null;}const _0x359f19=Window_ChoiceList[_0x526707(0x37c)][_0x526707(0x308)];Window_ChoiceList[_0x526707(0x37c)]['callOkHandler']=function(){const _0x4902fd=_0x526707;if(_0x3455ea[_0x4902fd(0x2b8)]()){const _0x5a4973=this['index']();_0x3455ea['onChoiceOk'](_0x5a4973,this);}_0x359f19[_0x4902fd(0x17b)](this);};const _0x96d017=Window_ChoiceList[_0x526707(0x37c)][_0x526707(0x2b0)];Window_ChoiceList[_0x526707(0x37c)][_0x526707(0x2b0)]=function(){const _0x11247d=_0x526707;if(_0x3455ea[_0x11247d(0x2b8)]()){const _0x252e4e=$gameMessage[_0x11247d(0x136)]();_0x3455ea[_0x11247d(0x1de)](_0x252e4e,this);}_0x96d017[_0x11247d(0x17b)](this);};class _0x24fdf8 extends Scene_MenuBase{['create'](){const _0x497513=_0x526707;super[_0x497513(0x326)](),this['createAllWindows']();}['logManager'](){return _0x3455ea;}[_0x526707(0x1bd)](){const _0x10d1e1=_0x526707,_0x2923b3=this['logManager']()[_0x10d1e1(0x25c)]()[_0x10d1e1(0x14b)]()['backgroundBitmap']();_0x2923b3?(this[_0x10d1e1(0x12f)]=new Sprite(_0x2923b3),this[_0x10d1e1(0x350)](this[_0x10d1e1(0x12f)])):super[_0x10d1e1(0x1bd)]();}['createAllWindows'](){const _0x32f041=_0x526707;this['createHelpWindow'](),this[_0x32f041(0x20b)](),this[_0x32f041(0x1d0)](),this[_0x32f041(0x366)]();}[_0x526707(0x343)](){const _0x3fa38d=_0x526707;return _0x3455ea[_0x3fa38d(0x25c)]()[_0x3fa38d(0x290)]();}[_0x526707(0x366)](){const _0x3f8154=_0x526707;this[_0x3f8154(0x13e)][_0x3f8154(0x2ef)](this[_0x3f8154(0x200)]),this[_0x3f8154(0x13e)][_0x3f8154(0x199)]();if(this[_0x3f8154(0x343)]()){this[_0x3f8154(0x13e)][_0x3f8154(0x179)]();return;}this['_logWindow']['selectlLastItem'](),this['_logWindow']['activate']();}[_0x526707(0x347)](){const _0x293b0a=_0x526707;super['start'](),this[_0x293b0a(0x200)]['refresh']();}[_0x526707(0x2a0)](){return 0x0;}[_0x526707(0x1c5)](){return![];}['helpAreaHeight'](){
                        const _0x13de5a=_0x526707;if(this[_0x13de5a(0x1c5)]())return super[_0x13de5a(0x181)]();return 0x0;}[_0x526707(0x333)](){return![];}['logWindowRect'](){const _0x395c74=_0x526707,_0x5bd191=_0x3455ea[_0x395c74(0x25c)]()[_0x395c74(0x14b)]()['logWindowRect']();if(_0x5bd191)return _0x5bd191;const _0x222654=this[_0x395c74(0x295)](),_0x5c058f=this['mainAreaLeft'](),_0xf6d1a1=this[_0x395c74(0x292)]()+_0x222654,_0x6a3fc6=this[_0x395c74(0x2b6)]()-_0x222654;return new Rectangle(_0x5c058f,_0xf6d1a1,Graphics[_0x395c74(0x2c4)],_0x6a3fc6);}[_0x526707(0x1d0)](){const _0x324d80=_0x526707,_0x26c3ac=this['logWindowRect'](),_0x25a6fd=new _0x3f3143(_0x26c3ac);this['needsHelpWindow']()&&_0x25a6fd[_0x324d80(0x1be)](this[_0x324d80(0x241)]),_0x25a6fd['setHandler']('ok',this[_0x324d80(0x383)][_0x324d80(0x243)](this)),_0x25a6fd['setHandler'](_0x324d80(0x262),this['onBacklogCancel']['bind'](this)),this[_0x324d80(0x200)]=_0x25a6fd,this[_0x324d80(0x13f)](_0x25a6fd);}['onBacklogOk'](){const _0x44d9e0=_0x526707,_0x41ee2f=this[_0x44d9e0(0x200)][_0x44d9e0(0x2b3)]();if(_0x41ee2f){const _0x384d4e=_0x41ee2f[_0x44d9e0(0x297)]();_0x384d4e&&ManoUZ_MessageLog[_0x44d9e0(0x26e)](_0x384d4e,{});}this[_0x44d9e0(0x200)]['activate']();}[_0x526707(0x266)](){const _0x531676=_0x526707;this[_0x531676(0x13e)]['visible']&&this[_0x531676(0x343)]()?(this[_0x531676(0x200)][_0x531676(0x1e1)](),this['_machinakaWindow'][_0x531676(0x179)]()):this['popScene']();}[_0x526707(0x295)](){const _0x33fa44=_0x526707;if(this[_0x33fa44(0x343)]()){const _0x53c678=_0x3455ea[_0x33fa44(0x25a)](),_0x5346e3=this[_0x33fa44(0x194)](_0x53c678,!![]);return _0x5346e3;}return 0x0;}[_0x526707(0x2c8)](){const _0x109401=_0x526707,_0x2218e5=this[_0x109401(0x2a0)](),_0x4ac4c6=this[_0x109401(0x292)](),_0x1a6a73=this['machinakaWindowHeight']();return new Rectangle(_0x2218e5,_0x4ac4c6,Graphics[_0x109401(0x2c4)],_0x1a6a73);}[_0x526707(0x20b)](){const _0x2e20a0=_0x526707,_0x10a0be=this[_0x2e20a0(0x2c8)](),_0xb15761=new _0x44bdad(_0x10a0be);_0xb15761[_0x2e20a0(0x2ba)]=this['machinakeModeEnabled'](),_0xb15761[_0x2e20a0(0x1dd)]('ok',this[_0x2e20a0(0x2d2)][_0x2e20a0(0x243)](this)),_0xb15761['setHandler'](_0x2e20a0(0x262),this['onMachinakaCancel'][_0x2e20a0(0x243)](this));const _0x4dbde6=_0x3455ea['createMachinakaList']();_0xb15761[_0x2e20a0(0x35e)](_0x4dbde6),this[_0x2e20a0(0x13e)]=_0xb15761,this[_0x2e20a0(0x13f)](_0xb15761);}[_0x526707(0x2d2)](){const _0x26a776=_0x526707,_0x359a69=this[_0x26a776(0x13e)][_0x26a776(0x2b3)]();this['_logWindow'][_0x26a776(0x35e)](_0x359a69[_0x26a776(0x36b)]()),this['_logWindow']['select'](0x0),this['_logWindow'][_0x26a776(0x179)]();}['onMachinakaCancel'](){this['popScene']();}}class _0x551c6d{['maxValue'](){return 0x1;}[_0x526707(0x2aa)](){return 0x1;}['valueRate'](){const _0x42a319=_0x526707,_0x23c646=Math[_0x42a319(0x358)](0x1,this[_0x42a319(0x157)]());return this[_0x42a319(0x2aa)]()/_0x23c646;}}class _0x43a2d9 extends PIXI['Graphics']{['redraw'](_0x17039f,_0x373e0b){const _0x55a022=_0x526707;this[_0x55a022(0x303)]['clear']();const _0x222b8e=-Math['PI']/0x2;this[_0x55a022(0x217)](0x0,0x0),this['arc'](_0x373e0b,_0x373e0b,_0x373e0b,_0x222b8e,Math['PI']*_0x17039f*0x2+_0x222b8e),this[_0x55a022(0x384)]();}}class _0x16fd27 extends _0x43a2d9{constructor(_0x2c3117){super(),this['_radius']=_0x2c3117;}[_0x526707(0x2fe)](_0x25fe22,_0x4ff8e1,_0x52cdb1){const _0x289b82=_0x526707;_0x25fe22[_0x289b82(0x153)](_0x3d2d54=>{const _0x439b23=_0x289b82,_0x58d822=new PIXI[(_0x439b23(0x22e))](_0x3d2d54[_0x439b23(0x229)]);this[_0x439b23(0x38b)]=_0x58d822,this[_0x439b23(0x133)]({'texture':_0x58d822,'width':_0x4ff8e1,'color':_0x52cdb1});});}[_0x526707(0x195)](_0x1458aa){const _0x46cfba=_0x526707;this[_0x46cfba(0x13b)](_0x1458aa,this[_0x46cfba(0x31b)]);}[_0x526707(0x2e0)](){}}function _0x2be8e5(_0x4e6ac3){const _0x421fab=_0x526707;return{'left':_0x4e6ac3['x'],'top':_0x4e6ac3['y'],'right':_0x4e6ac3['x']+_0x4e6ac3['width'],'bottom':_0x4e6ac3['y']+_0x4e6ac3[_0x421fab(0x1fb)]};}class _0xc9a97b extends PIXI[_0x526707(0x325)]{constructor(_0x1244b1){const _0x4fde8c=_0x526707;super(),this[_0x4fde8c(0x34a)]=new Rectangle(0x0,0x0,0x0,0x0),this['y']=-0x1e240,this['_behaviorList']=_0x1244b1,this[_0x4fde8c(0x382)]=_0x1244b1['createSpriteList'](),this['calcSize'](),this['addChild'](...this[_0x4fde8c(0x382)]);}get['width'](){const _0x318581=_0x526707;return this[_0x318581(0x172)];}get[_0x526707(0x1fb)](){const _0x594ff7=_0x526707;return this[_0x594ff7(0x1c8)];}[_0x526707(0x161)](){const _0x5e4354=_0x526707;if(this[_0x5e4354(0x382)][_0x5e4354(0x17f)]<=0x0){this[_0x5e4354(0x172)]=0x0,this[_0x5e4354(0x1c8)]=0x0;return;}const _0x7d7c08=this[_0x5e4354(0x382)][0x0],_0x26b172=_0x2be8e5(_0x7d7c08);for(let _0x4db463=0x1;_0x4db463<this['_buttonsSprites'][_0x5e4354(0x17f)];_0x4db463++){const _0x1fcd95=_0x2be8e5(this[_0x5e4354(0x382)][_0x4db463]);_0x26b172[_0x5e4354(0x17a)]=Math['min'](_0x26b172[_0x5e4354(0x17a)],_0x1fcd95[_0x5e4354(0x17a)]),_0x26b172['right']=Math[_0x5e4354(0x358)](_0x26b172[_0x5e4354(0x367)],_0x1fcd95[_0x5e4354(0x367)]),_0x26b172[_0x5e4354(0x1f9)]=Math[_0x5e4354(0x393)](_0x26b172[_0x5e4354(0x1f9)],_0x1fcd95[_0x5e4354(0x1f9)]),_0x26b172[_0x5e4354(0x1f0)]=Math[_0x5e4354(0x358)](_0x26b172[_0x5e4354(0x1f0)],_0x1fcd95[_0x5e4354(0x1f0)]);}this[_0x5e4354(0x172)]=Math[_0x5e4354(0x160)](_0x26b172[_0x5e4354(0x17a)]-_0x26b172[_0x5e4354(0x367)]),this[_0x5e4354(0x1c8)]=Math[_0x5e4354(0x160)](_0x26b172[_0x5e4354(0x1f9)]-_0x26b172['bottom']);}[_0x526707(0x202)](){const _0xf3b6f8=_0x526707;return this['_buttonsSprites'][_0xf3b6f8(0x34b)](_0x515e7a=>{const _0x8c6bec=_0xf3b6f8;return _0x515e7a[_0x8c6bec(0x257)]();});}['updateInput'](){const _0x9a6f9e=_0x526707;for(const _0x54f704 of this[_0x9a6f9e(0x382)]){_0x54f704[_0x9a6f9e(0x2e0)]();}}[_0x526707(0x20e)](){const _0x378698=_0x526707;this[_0x378698(0x2ba)]=!this[_0x378698(0x1ba)][_0x378698(0x25b)]();for(const _0x326210 of this['_buttonsSprites']){_0x326210[_0x378698(0x20e)]();}}[_0x526707(0x309)](){}[_0x526707(0x1ca)](_0x115f1a){return 0x0;}[_0x526707(0x37f)](_0xb7226c){}[_0x526707(0x1d4)](){return 0x0;}}class _0x3cb633 extends _0xc9a97b{[_0x526707(0x1d4)](){return this['height']-0x10;}[_0x526707(0x37f)](_0x10360f){const _0x2e5d83=_0x526707,_0x9784e7=this['parent']['width']-this[_0x2e5d83(0x2e7)],_0x524984=this[_0x2e5d83(0x1bb)][_0x2e5d83(0x1fb)]-this[_0x2e5d83(0x1fb)];this['x']=_0x9784e7+this[_0x2e5d83(0x1ba)][_0x2e5d83(0x38e)](),this['y']=_0x524984+this[_0x2e5d83(0x1ba)]['offsetY']();}}class _0x1a5366 extends _0xc9a97b{[_0x526707(0x37f)](_0x412ee3){const _0x2529ec=_0x526707,_0x42f5a4=this['parent']['width']-this[_0x2529ec(0x2e7)],_0x1d2942=_0x412ee3===0x0?this[_0x2529ec(0x1bb)][_0x2529ec(0x1fb)]:-this['height'];this['x']=_0x42f5a4+this[_0x2529ec(0x1ba)]['offsetX'](),this['y']=_0x1d2942+this['_behaviorList'][_0x2529ec(0x2ac)]();}[_0x526707(0x1ca)](_0x379e53){const _0x37effd=_0x526707;if(_0x379e53===0x1)return 0x0;if(_0x379e53===0x2)return-this[_0x37effd(0x1fb)];return this[_0x37effd(0x1fb)];}}class _0x4b048a extends _0xc9a97b{constructor(_0x6d4855){super(_0x6d4855);}[_0x526707(0x37f)](_0x22a537){const _0x4cf45b=_0x526707;this[_0x4cf45b(0x2ba)]=_0x22a537===0x2,this['x']=this[_0x4cf45b(0x1ba)][_0x4cf45b(0x38e)]()-this[_0x4cf45b(0x1bb)]['x'],this['y']=this[_0x4cf45b(0x1ba)][_0x4cf45b(0x2ac)]()-this['parent']['y'];}}const _0x12aca6=Window_ChoiceList[_0x526707(0x37c)][_0x526707(0x37f)];Window_ChoiceList[_0x526707(0x37c)]['updatePlacement']=function(){const _0x50bc4c=_0x526707;_0x12aca6['call'](this);if($gameMessage[_0x50bc4c(0x381)]()===0x2){const _0x18dd23=this['_messageWindow'][_0x50bc4c(0x278)]();this['y']+=_0x18dd23;}};const _0x16feff=Window_Message['prototype'][_0x526707(0x22a)];Window_Message[_0x526707(0x37c)][_0x526707(0x22a)]=function(_0x1c5138){const _0x1fd94d=_0x526707;this[_0x1fd94d(0x167)]=null;if(!_0x3455ea['isLogButtonEnabled']()){_0x16feff[_0x1fd94d(0x17b)](this,_0x1c5138);return;}const _0x8f1a2b=_0x1c5138[_0x1fd94d(0x21d)](),_0x3f3ba2=_0x3455ea[_0x1fd94d(0x219)]();this[_0x1fd94d(0x167)]=_0x3f3ba2,_0x8f1a2b[_0x1fd94d(0x1fb)]+=_0x3f3ba2[_0x1fd94d(0x1d4)](),_0x16feff['call'](this,_0x8f1a2b),this[_0x1fd94d(0x350)](_0x3f3ba2);};function _0x4a29a0(_0x65f989){const _0x31e67d=_0x526707;return _0x65f989[_0x31e67d(0x167)];}Window_Message[_0x526707(0x37c)]['logButtonAreaHeight']=function(){const _0x5cade0=_0x526707,_0x14e5b3=_0x4a29a0(this);if(_0x14e5b3)return _0x14e5b3[_0x5cade0(0x1ca)](this[_0x5cade0(0x35c)]);return 0x0;};const _0x432ff0=Window_Message[_0x526707(0x37c)][_0x526707(0x273)];Window_Message[_0x526707(0x37c)][_0x526707(0x273)]=function(){const _0x5b379e=_0x526707,_0x38443b=_0x432ff0[_0x5b379e(0x17b)](this),_0x1a7fc6=_0x4a29a0(this);if(_0x1a7fc6)return _0x38443b-_0x1a7fc6[_0x5b379e(0x1d4)]();return _0x38443b;};
                        const _0x31912a=Window_Message[_0x526707(0x37c)][_0x526707(0x32f)];Window_Message['prototype'][_0x526707(0x32f)]=function(_0x3af6b4){const _0x4c15ef=_0x526707,_0x22a518=this[_0x4c15ef(0x1aa)](),_0xd9f387=Math[_0x4c15ef(0x351)](this[_0x4c15ef(0x2a5)]['outputHeight']/_0x22a518);_0x3455ea[_0x4c15ef(0x33d)](Math['min'](_0xd9f387,0x4)),_0x31912a[_0x4c15ef(0x17b)](this,_0x3af6b4);};const _0x5eb985=Window_Message[_0x526707(0x37c)][_0x526707(0x267)];Window_Message['prototype']['onEndOfText']=function(){const _0x4458e3=_0x526707,_0x36e737=this[_0x4458e3(0x1aa)](),_0x523ca5=Math[_0x4458e3(0x351)](this[_0x4458e3(0x2a5)][_0x4458e3(0x1b2)]/_0x36e737);_0x3455ea[_0x4458e3(0x33d)](Math[_0x4458e3(0x393)](_0x523ca5,0x4)),_0x3455ea[_0x4458e3(0x141)](),_0x5eb985['call'](this);};const _0x1c9888=Window_Message[_0x526707(0x37c)]['startMessage'];Window_Message[_0x526707(0x37c)][_0x526707(0x20e)]=function(){const _0x729dbe=_0x526707;_0x1c9888[_0x729dbe(0x17b)](this);const _0x261043=_0x4a29a0(this);if(_0x261043){_0x3455ea[_0x729dbe(0x2d8)]()&&(this[_0x729dbe(0x371)]=!![]);const _0x57b07f=this[_0x729dbe(0x18f)][_0x729dbe(0x2ca)]($gameMessage[_0x729dbe(0x36d)]());_0x3455ea[_0x729dbe(0x20e)](_0x57b07f,this['_textState'][_0x729dbe(0x2e4)]),_0x261043['startMessage']();}};const _0xf1901d=Window_Message[_0x526707(0x37c)][_0x526707(0x305)];Window_Message[_0x526707(0x37c)][_0x526707(0x305)]=function(){const _0x36f736=_0x526707;_0x3455ea[_0x36f736(0x19d)](),_0xf1901d[_0x36f736(0x17b)](this),_0x3455ea[_0x36f736(0x142)]();};const _0x5a40f2=Window_Message['prototype'][_0x526707(0x37f)];Window_Message[_0x526707(0x37c)]['updatePlacement']=function(){const _0x24dba2=_0x526707;_0x5a40f2['call'](this);const _0x1fcca=_0x4a29a0(this);_0x1fcca&&_0x1fcca[_0x24dba2(0x37f)](this[_0x24dba2(0x35c)]);};function _0x3a7a93(_0x5af72f){const _0x38dfd4=_0x526707;return _0x5af72f[_0x38dfd4(0x268)]()&&!_0x5af72f[_0x38dfd4(0x26f)]();}function _0x13607f(_0x3c5222){const _0x32d24e=_0x526707;if($gameParty[_0x32d24e(0x1e6)]())return;_0x3455ea[_0x32d24e(0x17e)](),_0x3c5222&&_0x3c5222['updateInput']();}const _0x59f2db=Window_Message[_0x526707(0x37c)][_0x526707(0x17e)];Window_Message[_0x526707(0x37c)][_0x526707(0x17e)]=function(){const _0x3d05ef=_0x526707;!this[_0x3d05ef(0x2a5)]&&_0x3a7a93(this)&&_0x13607f(_0x4a29a0(this));const _0x27a405=this['pause'],_0x30ee85=_0x59f2db['call'](this);if(!this['pause'])return _0x30ee85;if(!_0x3455ea[_0x3d05ef(0x321)]())return _0x30ee85;!_0x27a405&&_0x3455ea['startAutoTimer']();_0x3455ea['updateAutoTimer']();if(_0x3455ea[_0x3d05ef(0x370)]())return _0x3455ea[_0x3d05ef(0x1ed)](),this['pause']=![],this[_0x3d05ef(0x2a5)]=null,this[_0x3d05ef(0x305)](),![];return!![];};const _0x5a21d2=Window_Message['prototype'][_0x526707(0x24f)];Window_Message[_0x526707(0x37c)][_0x526707(0x24f)]=function(){const _0x1ea99e=_0x526707,_0x1b096a=_0x4a29a0(this);if(_0x1b096a&&TouchInput[_0x1ea99e(0x16f)]()&&_0x1b096a[_0x1ea99e(0x202)]())return![];return _0x5a21d2[_0x1ea99e(0x17b)](this);};const _0x28e7ae=Scene_Map[_0x526707(0x37c)][_0x526707(0x233)];Scene_Map[_0x526707(0x37c)][_0x526707(0x233)]=function(){const _0x3025eb=_0x526707;_0x3455ea['setBattleMode'](![]),_0x28e7ae[_0x3025eb(0x17b)](this),_0x3455ea[_0x3025eb(0x2d8)]()&&(this[_0x3025eb(0x16a)]['openness']=0xff);};const _0x1dd2f6=Scene_Battle[_0x526707(0x37c)][_0x526707(0x233)];Scene_Battle['prototype'][_0x526707(0x233)]=function(){const _0x59aaed=_0x526707;_0x3455ea[_0x59aaed(0x27a)](!![]),_0x1dd2f6[_0x59aaed(0x17b)](this);};const _0x126c36=Game_Map['prototype'][_0x526707(0x159)];Game_Map[_0x526707(0x37c)][_0x526707(0x159)]=function(){const _0x2b6334=_0x526707,_0x3db33c=_0x126c36[_0x2b6334(0x17b)](this);if(_0x3db33c){const _0x217e68=this[_0x2b6334(0x1ab)][_0x2b6334(0x312)](),_0x31d798=this['event'](_0x217e68);_0x31d798&&_0x3455ea['onMapEventStarted'](_0x31d798,this['_mapId']);}return _0x3db33c;};const _0x4f01f6=Game_Map[_0x526707(0x37c)][_0x526707(0x299)];Game_Map[_0x526707(0x37c)]['updateInterpreter']=function(){const _0x184cb6=_0x526707,_0xefd56d=this[_0x184cb6(0x1ab)]['isRunning']();_0x4f01f6[_0x184cb6(0x17b)](this),_0xefd56d&&!this[_0x184cb6(0x1ab)]['isRunning']()&&_0x3455ea[_0x184cb6(0x255)]();};const _0x51ec5c=Window_MenuCommand[_0x526707(0x37c)][_0x526707(0x220)];Window_MenuCommand[_0x526707(0x37c)]['addOriginalCommands']=function(){const _0x3db7a5=_0x526707;_0x51ec5c[_0x3db7a5(0x17b)](this);const _0x1e15fa=_0x3455ea[_0x3db7a5(0x25c)]()['menuCommand'](),_0x7cf0a9=_0x1e15fa[_0x3db7a5(0x1d3)]['text']();_0x7cf0a9&&this[_0x3db7a5(0x28a)](_0x7cf0a9,_0x1e15fa[_0x3db7a5(0x386)]);};const _0x219270=Scene_Menu[_0x526707(0x37c)][_0x526707(0x15b)];Scene_Menu['prototype'][_0x526707(0x15b)]=function(){const _0x134741=_0x526707;_0x219270[_0x134741(0x17b)](this);const _0x10c732=_0x3455ea['readOnryData']()['menuCommand']();this[_0x134741(0x293)][_0x134741(0x1dd)](_0x10c732[_0x134741(0x386)],()=>{SceneManager['push'](_0x24fdf8);});};class _0x402e20{constructor(_0x1ccbed,_0x4570d1,_0x2e60ce){const _0x3ae778=_0x526707;this[_0x3ae778(0x135)]=_0x1ccbed,this[_0x3ae778(0x2b4)]=_0x4570d1,this['_func']=_0x2e60ce;}[_0x526707(0x1b8)](_0x515442){const _0x262bdc=_0x526707,_0x22932d={},_0x59ae7d=Math[_0x262bdc(0x393)](_0x515442[_0x262bdc(0x17f)],this['_paramNames'][_0x262bdc(0x17f)]);for(let _0x2aa38d=0x0;_0x2aa38d<_0x59ae7d;++_0x2aa38d){const _0x3559db=this[_0x262bdc(0x2b4)][_0x2aa38d];_0x22932d[_0x3559db]=_0x515442[_0x2aa38d];}return _0x22932d;}[_0x526707(0x269)](_0x1558e0){const _0xe209ce=_0x526707,_0x39d7aa=this[_0xe209ce(0x1b8)](_0x1558e0);this[_0xe209ce(0x22b)](_0x39d7aa);}[_0x526707(0x22b)](_0x38eb6c){const _0x40a2cf=_0x526707;this[_0x40a2cf(0x362)](_0x38eb6c);}}class _0x290ac{constructor(_0x6ced5b){const _0x30799e=_0x526707;this['_map']=new Map(),this[_0x30799e(0x2c2)]=_0x6ced5b;}[_0x526707(0x296)](_0x2a92b6,_0x39f315,_0x4060a7){const _0x99c8d0=_0x526707;Utils[_0x99c8d0(0x1a4)]==='MZ'&&this[_0x99c8d0(0x2a7)](_0x2a92b6,_0x4060a7),this[_0x99c8d0(0x32a)]()&&this['registerCommandMV'](_0x2a92b6,_0x39f315,_0x4060a7);}[_0x526707(0x32a)](){return Utils['RPGMAKER_NAME']==='MV';}['registerCommandMZ'](_0x4b9aec,_0x3f9e48){const _0x34f5b8=_0x526707;PluginManager[_0x34f5b8(0x296)](this['_pluginName'],_0x4b9aec,_0x3f9e48);}[_0x526707(0x23c)](_0x1afd76,_0x4e7f0f,_0x4f50fc){const _0x27e0d7=_0x526707,_0x27fb3f=new _0x402e20(_0x1afd76,_0x4e7f0f,_0x4f50fc);this[_0x27e0d7(0x27e)][_0x27e0d7(0x2e3)](_0x1afd76,_0x27fb3f);}[_0x526707(0x1d8)](_0x2a0717,_0x266ca4,_0x1de8b7){const _0x56c51=_0x526707,_0x3990af=this[_0x56c51(0x27e)][_0x56c51(0x198)](_0x266ca4);if(_0x3990af){const _0x726650=_0x3990af['makeMZ_arg'](_0x1de8b7);return _0x3990af[_0x56c51(0x22b)](_0x726650),!![];}return![];}}const _0x4d6f23=new _0x290ac(_0x3b171d);_0x4d6f23[_0x526707(0x296)](_0x526707(0x2b1),[],()=>{const _0x45f025=_0x526707;SceneManager[_0x45f025(0x1f2)](_0x24fdf8);}),_0x4d6f23[_0x526707(0x296)](_0x526707(0x1d9),[],_0x477e2e=>{const _0x5ea02d=_0x526707,_0x57f39b=String(_0x477e2e[_0x5ea02d(0x2e2)]);_0x3455ea[_0x5ea02d(0x2a8)](_0x57f39b);}),_0x4d6f23[_0x526707(0x296)]('ClearAll',[],()=>{const _0x53f85d=_0x526707;_0x3455ea[_0x53f85d(0x270)]();}),_0x4d6f23['registerCommand'](_0x526707(0x248),[],_0x23b53d=>{const _0x21eecc=_0x526707;_0x3455ea[_0x21eecc(0x211)]();}),_0x4d6f23[_0x526707(0x296)]('GetLogSize',[],_0x301ca1=>{const _0x1f4644=_0x526707,_0x2531ad=Number(_0x301ca1['variableId']),_0x2262a6=_0x3455ea['getLogSize']();$gameVariables[_0x1f4644(0x195)](_0x2531ad,_0x2262a6);}),_0x4d6f23[_0x526707(0x296)](_0x526707(0x324),[_0x526707(0x1cc)],_0x16e621=>{const _0xcfb17c=_0x526707;_0x3455ea[_0xcfb17c(0x13d)](_0x16e621[_0xcfb17c(0x341)]===_0xcfb17c(0x15d));}),_0x4d6f23['registerCommand']('GetAutoMode',[_0x526707(0x1cc)],_0x1a516e=>{const _0x64d2ae=_0x526707,_0x723585=Number(_0x1a516e['swtichId']),_0x49d746=_0x3455ea[_0x64d2ae(0x38f)]();$gameSwitches[_0x64d2ae(0x195)](_0x723585,_0x49d746);}),_0x4d6f23[_0x526707(0x296)]('SetJumpTarget',[_0x526707(0x271)],function(_0x241d52){const _0x534cf1=_0x526707;this['setJumpTarget'](_0x241d52[_0x534cf1(0x271)]);}),_0x4d6f23[_0x526707(0x296)](_0x526707(0x1ec),[_0x526707(0x1c9)],_0x120fa4=>{const _0x5eefc7=_0x526707,_0x2fdae2=Number(_0x120fa4[_0x5eefc7(0x1c9)]);$gameSwitches[_0x5eefc7(0x195)](_0x2fdae2,_0x3455ea[_0x5eefc7(0x35b)]());}),_0x4d6f23[_0x526707(0x296)](_0x526707(0x1f4),[],()=>{const _0xf5a665=_0x526707,_0x556f71=_0x3455ea[_0xf5a665(0x36f)]()[_0xf5a665(0x365)]();for(const _0x220a65 of _0x556f71){console[_0xf5a665(0x353)](_0x220a65);}}),_0x4d6f23[_0x526707(0x296)]('GetAutoWaitTime',[],_0x395c9d=>{const _0x1c4295=_0x526707,_0x4e2afe=_0x3455ea[_0x1c4295(0x239)]()[_0x1c4295(0x152)](),_0x1b36b0=Number(_0x395c9d[_0x1c4295(0x2f0)]);$gameVariables[_0x1c4295(0x195)](_0x1b36b0,_0x4e2afe);}),_0x4d6f23[_0x526707(0x296)]('SetAutoWaitTime',[],_0x1d37aa=>{const _0x74591d=_0x526707,_0x41f524=Number(_0x1d37aa[_0x74591d(0x2f0)]),_0x3bea87=$gameVariables['value'](_0x41f524);!isNaN(_0x3bea87)&&_0x3455ea[_0x74591d(0x239)]()[_0x74591d(0x1f5)](_0x3bea87);}),_0x4d6f23[_0x526707(0x296)]('SetLogLimitSizeBasic',[],_0x107820=>{const _0x153659=_0x526707,_0x2d2c85=Number(_0x107820[_0x153659(0x2f0)]),_0x536d1e=$gameVariables['value'](_0x2d2c85);_0x3455ea[_0x153659(0x239)]()[_0x153659(0x2cd)](_0x536d1e);}),_0x4d6f23[_0x526707(0x296)](_0x526707(0x344),[],_0x44e754=>{const _0x5c2b82=_0x526707,_0x93e6bd=Number(_0x44e754[_0x5c2b82(0x2f0)]),_0x93d814=_0x3455ea[_0x5c2b82(0x239)]()['getLogLimitSizeBasic']();$gameVariables[_0x5c2b82(0x195)](_0x93e6bd,_0x93d814);}),_0x4d6f23[_0x526707(0x296)](_0x526707(0x1f8),[],_0x3ab1bd=>{const _0x30c9e1=_0x526707,_0x32e58b=Number(_0x3ab1bd[_0x30c9e1(0x2f0)]),_0x181ca8=$gameVariables['value'](_0x32e58b);_0x3455ea[_0x30c9e1(0x239)]()['setLogLimitExtends'](_0x181ca8);}),_0x4d6f23[_0x526707(0x296)](_0x526707(0x307),[],_0x41d060=>{const _0x20d79a=_0x526707,_0x43c85c=Number(_0x41d060[_0x20d79a(0x2f0)]),_0x5433ce=_0x3455ea[_0x20d79a(0x239)]()[_0x20d79a(0x1d5)]();$gameVariables[_0x20d79a(0x195)](_0x43c85c,_0x5433ce);
                        }),_0x4d6f23[_0x526707(0x296)](_0x526707(0x1a7),[],_0x123b1e=>{const _0x345aa2=_0x526707,_0x191383=_0x3455ea['option']()[_0x345aa2(0x1a0)](),_0x50775a=Number(_0x123b1e[_0x345aa2(0x1c9)]);$gameSwitches[_0x345aa2(0x195)](_0x50775a,_0x191383);});const _0x19bc85=_0x526707(0x289),_0x38d603=ConfigManager[_0x526707(0x26a)];ConfigManager[_0x526707(0x26a)]=function(){const _0x8083c7=_0x526707,_0x2af183=_0x38d603[_0x8083c7(0x17b)](this),_0x273f7a=_0x3455ea['cloneOptionValue']();return _0x2af183[_0x19bc85]=_0x273f7a,_0x2af183;};const _0x64681e=ConfigManager[_0x526707(0x221)];ConfigManager[_0x526707(0x221)]=function(_0x56f58c){const _0x505a9b=_0x526707;_0x64681e['call'](this,_0x56f58c);const _0x21da5a=_0x56f58c[_0x19bc85];_0x3455ea[_0x505a9b(0x2c0)](_0x21da5a);};const _0xc64c78=DataManager[_0x526707(0x2bd)];DataManager['makeSaveContents']=function(){const _0x2c0438=_0x526707,_0x2cf40b=_0xc64c78[_0x2c0438(0x17b)](this);return _0x3455ea['writeSaveContents'](_0x2cf40b),_0x2cf40b;};const _0x2ae4f5=DataManager['extractSaveContents'];DataManager['extractSaveContents']=function(_0x497b13){const _0x39545e=_0x526707;_0x2ae4f5[_0x39545e(0x17b)](this,_0x497b13),_0x3455ea[_0x39545e(0x1e9)](_0x497b13);};const _0x382f97=DataManager[_0x526707(0x2ad)];DataManager[_0x526707(0x2ad)]=function(){const _0x4180a7=_0x526707;_0x382f97['call'](this),_0x3455ea[_0x4180a7(0x291)]();};const _0x141cdb=DataManager[_0x526707(0x1bf)];DataManager[_0x526707(0x1bf)]=function(){const _0x1c1aae=_0x526707;_0x141cdb[_0x1c1aae(0x17b)](this),_0x3455ea[_0x1c1aae(0x2bd)]();};const _0xe7cac7=Scene_Boot['prototype'][_0x526707(0x347)];Scene_Boot[_0x526707(0x37c)][_0x526707(0x347)]=function(){const _0x1a977b=_0x526707;_0xe7cac7[_0x1a977b(0x17b)](this),_0x78841d[_0x1a977b(0x374)](),_0x3455ea[_0x1a977b(0x294)]();};function _0x211acf(_0x42ba55,_0x1c9e21){window[_0x1c9e21]=_0x42ba55;}const _0x7e6577=[_0x36c076,_0x1b41ac,_0x28ba4a,_0x470fe1];for(const _0x45e8be of _0x7e6577){_0x211acf(_0x45e8be,_0x45e8be[_0x526707(0x34c)]);}return new _0x5372d5(_0x3455ea);}());function _0xeca8(){const _0x44f859=['format','createButtonSprite','windowMessageInit','logManager','5xjDTSZ','createMachinakaWindow','makeNewLog','_title','startMessage','_speed','updateAutoTimer','clearOldData','autoWaitTime','isMacinakaMode','_windowRect','isEnabled','skipButton','beginFill','setTitle','createLogButtonSprites','setText','faceName','isEmpty','clone','canSave','maxItems','addOriginalCommands','applyData','topItemIndex','onAutosaveFailure','topIndex','setLocal','makeItemList','_switchId','filter','baseTexture','initialize','callMZ','currentLocal','topLineIndex','Texture','quickLoad','_currentTime','locale','cloneDefaultOption','createDisplayObjects','_eventId','voiceRepeatButton','regex','pageup','isAbsolute','option','lastItemIndex','_readOnlyData','registerCommandMV','isNumberInput','_windowFileName','logSizeYellow','onClick','_helpWindow','_scrollIndex','bind','voiceIcon','_format','setTextTerminate','_currnet','CleanupOldData','isInside','ko_KR','write','quickSave','faceRect','_gauge','isTriggered','setShowFast','saveButton','setLastVoiceParam','error','_name','onEndEvent','_logListWindow','isBeingTouched','callDrawIcon','layout','machinakaLines','isButtonDisabled','readOnryData','_option','_enabled','refreshLang','isAutoMode','_logSwitch','cancel','choiceFormat','map','logSizeRed','onBacklogCancel','onEndOfText','isOpen','convertCall','makeData','onAudioLoadError','faceHeight','messageLog','playVoice','isClosing','clearLog','label','iconWidth','contentsHeight','isPlaying','973244QJsmES','_voiceReg','onStartMessage','logButtonAreaHeight','isItemChoice','setBattleMode','itemRectForText','_rootMapId','onSaveLoaded','_map','184032EvEyHL','skipSwitch','_logWrite','bitmap','_facename','getGaugeColor','logWindowRect','<br>','playClickSound','forceSelect','UZMSGLOG_CONFIG','addCommand','src','saveCurrentLog','itemAt','setRootMap','createSpriteList','isMachinakaModeEnabled','onNewGame','mainAreaTop','_commandWindow','onBoot','machinakaWindowHeight','registerCommand','voiceParam','_channelFunc','updateInterpreter','lineText','_hotFrame','lastItem','playBuzzerSound','nameIsMeetsTitle','getCurrentText','mainAreaLeft','lineIndex','プラグインファイルの名前を変更してはいけません<br>','cold','tryReadingSaveContents','_textState','cloneOptionValue','registerCommandMZ','setMachinakaTitle','isBattleMode','currentValue','_choice','offsetY','setupNewGame','changeAutoMode','cloneValue','callCancelHandler','Show','setHotFrame','currentItem','_paramNames','itemFrameColor','mainAreaHeight','needsNextMessage','isLogWriteEnabled','createChoiceItemText','visible','_parallelInputLock','_cancelText','makeSaveContents','colSpacing','isInputEnabled','setOptionValue','nextTopIndex','_pluginName','gaugeColor','boxWidth','fileName','createSprite','machinakaModeSwitch','machinakaWindowRect','isValid','convertEscapeCharacters','jumpTo','setWorkaround','setLogLimitBasic','shift','logLimitExtends','drawItemBackground','setContents','onMachnakaOk','_type','callDrawFace','Original\x20file\x20name:\x20','callUpdateHelp','open','needsShowFast','choiceCancelText','timerValue','loadFace','lineWidth','initSwitch','machinakaModeLines','texture','update','_version','title','set','text','checkLogSize','play','width','smoothSelect','radius','bottomItemIndex','_msg','createEmptySaveContents','_workaround','cancelText','setLogListWindow','variableId','_autoSpeedList','hot','parse','voiceIconIndex','hasVoice','_temporaly','windowSkinBitmap','loadObject','faceIndex','itemRect','_item','drawFace','goto','setupBitmapStyle','_pan','setLastVoiceBuffer','makeCache','windowskin','geometry','hasLogList','terminateMessage','_menuCommand','GetLogLimitSizeExtends','callOkHandler','endMessage','wheelY','match','color','ManoUZ_MessageLog','command250','getWorkaround','command101','readSwitch','eventId','_mapId','autoButton','_numLines','itemStyle','_auto','_errorFiles','processTouch','index','_radius','keepingAutoMode','clear','300468yNsqZz','_machinakaList','_logWriteOnBattle','isTextAutoMode','stop','lineSpacing','SetAutoMode','Container','create','close','saveObject','pressedSound','isMVcommandEnabeled','createMinimize','_seBuffer','_offsetY','timeRate','newPage','setParallelMode','setPlayVoiceFunction','disableSwitch','isBottomHelpMode','lastCodeIndex','loadBitmap','parentId','_lastIndex','stopVoice','_voiceList','removeChild','hotFrame','onAutoSaveSuccess','addLines','extractSaveContents','autoGauge','numItemLines','automode','_choiceText','machinakeModeEnabled','GetLogLimitSizeBasic','addItem','isItemEnalbled','start','bottomLineIndex','_itemstyle','_localBoundsRect','some','name','rowSpacing','maxPageRows','autoGaugeRate','addChild','round','playOkSound','table','needsDrawItem','_logItem','resetTemporaly','_logList','max','_messageStream','openOptionScene','hasLastVoice','_positionType','_overlapType','setList','_color','ja_JP','loadButton','_func','needsDrawBackground','_value','createProxy','linkWindow','right','onVoiceStop','optionNormalize','isLocationMatch','multiLineItems','otherLocationMatch','speakerName','getLogItemStyle','getContents','needsTextTerminate','_showFast','logSize','getLogItem','refresh','pluginVersion','drawIcon','_autoTemporary','needsDrawFace','_needsShowFast','unshift','flipAutoMode','prototype','_volume','pan','updatePlacement','test','choicePositionType','_buttonsSprites','onBacklogOk','endFill','getSaveContents','symbol','speakerNameFormat','353554pafCfI','itemPadding','loadGame','_texture','_disableSwitch','setColdFrame','offsetX','getAutoMode','updateFrame','buttonSetting','_faceindex','min','_se','onMapEventStarted','_backgroundSprite','_buttons','_parallelMode','voice','lineTextureStyle','_list','_commandName','choiceCancelType','_lineIndex','loadWindowskin','add','baseRect','redraw','selectlLastItem','setAutoMode','_machinakaWindow','addWindow','_behavior','onEnedOfText','refreshAutoKeeping','GetAutoSpeed','pos','nextBottomIndex','faceWidth','_symbol','_textuerName','playSe','mapId','logStyle','freamColor','_machinakaMode','coldFrame','isTopItem','isButtonOn','windowOverlap','getAutoWaitTime','addLoadListener','correctDataErrors','menuCommand','_cache','maxValue','setLocation','setupStartingMapEvent','initSwitchs','createCommandWindow','_offsetX','true','_pitch','_choiceStyle','abs','calcSize','windowRect','defaultQuickSaveFileName','_background','obj','itemRectWithPadding','_logButtonGroop','323090bRtyls','_contents','_messageWindow','exec','clearTextItem','has','files','isRepeated','value','list','_width','clearLastCodeIndex','resetTimer','42910xhKaTD','isVoiceStoped','_logManager','needsVoiceIconRender','activate','left','call','isClickEnabled','needsAutoModeStop','updateInput','length','isLogSaveEnabled','helpAreaHeight','_table','repeatLastVoice','isButtonHot','hasName','isChoiceMatch','logLimitBasic','setScrollIndex','textLines','backgroundBitmap','isSceneChanging','_text','auto','drawTextEx','_nameBoxWindow','createMachinakaList','isBusy','45etRTSN','version','calcWindowHeight','setValue','numLines','_macinakaMode','get','selectLastItem','windowFileName','_style','isLongPressed','onTerminateMessage','6bKtggN','\x0ascroll:','isKeepingAutoMode','_onOff','ru_RU','logWriteOnBattle','RPGMAKER_NAME','updateAutoTime','calcRectHeight','GetKeepingAutoMode','setBehavior','Current\x20file\x20name:\x20','lineHeight','_interpreter','266021fIhTku','_index','_defaultOption','_childInterpreter','logquicksave','getStyle','outputHeight','none','en_US','_defaultState','_frameColor','_coldFrame','makeMZ_arg','setLastCodeIndex','_behaviorList','parent','setLastVoice','createBackground','setHelpWindow','createGameObjects','pagedown','de_DE','setLogLimitExtends','backlogButton','drawItem','needsHelpWindow','isCurrentItemEnabled','createAutoGauge','_height','switchId','movementAmountOfChoice','_speakerName','mode','_machinakaFocus','logWriteSwitch','quickSaveFileName','createLogWindow','_swicthId','現在のファイル名:\x20','commandName','windowStretchY','getLogLimitSizeExtends','pushScene','isVoiceFile','callMV','SetTitle','isIconLeft','isNwjs','event','setHandler','onChoiceOk','_logStyle','inside','deselect','_autoGaugeFunc','updateHelp','loadSystem','choiceText','inBattle','time','isRunning','readSaveContents','machinakaRect','_voice','HasLastVoice','endAutoTimer','_layout','makeStateText','bottom','absolute','push','onMapTransfer','ShowConsloeProxy','setAutoWaitTime','slice','onLabel','SetLogLimitSizeExtends','top','getLogSize','height','titleText','_battleMode','volume','macinakaModeDefault','_logWindow','setAutoGauge','isAnyButtonOverlaped','isEventRunning','lastVoice','notitle'];_0xeca8=function(){return _0x44f859;};return _0xeca8();}